<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################




$var_mod = "";

$var_mod[0] = "estendi_ultima_data";
$var_mod[1] = "apertura_tag_font";
$var_mod[2] = "chiusura_tag_font";
$var_mod[3] = "periodi_menu";
$var_mod[4] = "periodi_no_richieste";
$var_mod[5] = "stile_soldi";
$var_mod[6] = "stile_data";
$var_mod[7] = "fr_Valuta_sing";
$var_mod[8] = "fr_Valuta_plur";
$var_mod[9] = "anteponi_nome_valuta";
$var_mod[10] = "utente_liste";
$var_mod[11] = "tariffe_mostra";
$var_mod[12] = "nomi_tariffe_imposte";
$var_mod[13] = "chiedi_numero_appartamenti_per_tipologia";
$var_mod[14] = "massimo_numero_appartamenti_per_tipologia";
$var_mod[15] = "fr_appartamento";
$var_mod[16] = "fr_appartamenti";
$var_mod[17] = "aggiungi_altre_tipologie";
$var_mod[18] = "massimo_numero_altre_tipologie";
$var_mod[19] = "cerca_appartamenti_vicini";
$var_mod[20] = "chiedi_numero_persone";
$var_mod[21] = "massimo_numero_persone";
$var_mod[22] = "costo_aggiungi_letti";
$var_mod[23] = "massimo_numero_letti_aggiuntivi";
$var_mod[24] = "aggiungi_costi_fissi";
$var_mod[25] = "chiedi_costi_aggiuntivi_di_pag_inserzione";
$var_mod[26] = "numero_colonne_costi_aggiuntivi";
$var_mod[27] = "costi_aggiuntivi_mostra";
$var_mod[28] = "nomi_costi_agg_imposti";
$var_mod[29] = "categorie_costi_agg_imposte";
$var_mod[30] = "campi_codici_promo";
$var_mod[31] = "costi_campi_codici_promo";
$var_mod[32] = "assegna_con_regola2";
$var_mod[33] = "considera_motivazioni_regola1";
$var_mod[34] = "mostra_frase_alternativa_regola1";
$var_mod[35] = "fr_alternativa_regola1";
$var_mod[36] = "mostra_caparra";
$var_mod[37] = "mostra_giorni_pieni";
$var_mod[38] = "mostra_bottone_paypal";
$var_mod[39] = "nome_modello_paypal";
$var_mod[40] = "mostra_richiesta_via_mail";
$var_mod[41] = "indirizzo_email";
$var_mod[42] = "manda_copia_richiesta_email";
$var_mod[43] = "maschera_email";
$var_mod[44] = "mostra_quadro_disponibilita";
$var_mod[45] = "raggruppa_quadro_disponibilita_con_regola_2";
$var_mod[46] = "raggruppa_quadro_disponibilita_con_persone";
$var_mod[47] = "colore_sfondo_quadro_disponibilita";
$var_mod[48] = "colore_inizio_settimana_quadro_disponibilita";
$var_mod[49] = "colore_libero_quadro_disponibilita";
$var_mod[50] = "colore_occupato_quadro_disponibilita";
$var_mod[51] = "apertura_font_quadro_disponibilita";
$var_mod[52] = "chiusura_font_quadro_disponibilita";
$var_mod[53] = "mostra_numero_liberi_quadro_disponibilita";
$var_mod[54] = "allinea_disponibilita_con_arrivo";
$var_mod[55] = "utente_messaggio";
$var_mod[56] = "origine_prenotazione";
$var_mod[57] = "chiedi_cognome";
$var_mod[58] = "chiedi_nome";
$var_mod[59] = "chiedi_email";
$var_mod[60] = "chiedi_sesso";
$var_mod[61] = "chiedi_datanascita";
$var_mod[62] = "chiedi_documento";
$var_mod[63] = "chiedi_nazione";
$var_mod[64] = "chiedi_citta";
$var_mod[65] = "chiedi_regione";
$var_mod[66] = "chiedi_via";
$var_mod[67] = "chiedi_numcivico";
$var_mod[68] = "chiedi_cap";
$var_mod[69] = "chiedi_telefono";
$var_mod[70] = "chiedi_telefono2";
$var_mod[71] = "chiedi_telefono3";
$var_mod[72] = "chiedi_fax";
$var_mod[73] = "chiedi_codfiscale";
$var_mod[74] = "chiedi_partitaiva";
$var_mod[75] = "chiedi_commento";
$var_mod[76] = "chiedi_oracheckin";
$var_mod[77] = "chiedi_metodopagamento";
$var_mod[78] = "metodi_pagamento_da_chiedere";
$var_mod[79] = "nomi_metodi_pagamento_imposti";
$var_mod[80] = "campi_form_personalizzati";
$var_mod[81] = "chiedi_campi_form_personalizzati";
$var_mod[82] = "ins_campi_form_personalizzati";
$var_mod[83] = "campi_form_doc_condizioni";
$var_mod[84] = "chiedi_campi_form_doc_condizioni";
$var_mod[85] = "apertura_tag_font_rosse";
$var_mod[86] = "chiusura_tag_font_rosse";
$var_mod[87] = "stile_tabella_prenotazione";
$var_mod[88] = "mostra_calendario_scelta_date";
$var_mod[89] = "stile_riquadro_calendario";
$var_mod[90] = "stile_tabella_calendario";
$var_mod[91] = "stile_bottoni_calendario";
$var_mod[92] = "stile_bottone_apertura_calendario";
$var_mod[93] = "spostamento_orizzontale_calendario";
$var_mod[94] = "colore_data_attiva_calendario";
$var_mod[95] = "colore_data_selezionata_calendario";
$var_mod[96] = "file_css_frame";
$var_mod[97] = "apri_nuova_finestra_da_frame";
$var_mod[98] = "larghezza_finestra_da_frame";
$var_mod[99] = "altezza_finestra_da_frame";
$var_mod[100] = "tema_modello";

$num_var_mod = count($var_mod);




function recupera_var_modello_disponibilita ($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,$var_per_crea_mod,$anno_modello,$PHPR_TAB_PRE) {

$linee_file = file("$percorso_cartella_modello/$nome_file");
$num_linee_file = count($linee_file);
if (substr($linee_file[0],0,70) == "<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed']) { ?>") $linee_file[0] = substr($linee_file[0],70);
if (substr($linee_file[($num_linee_file - 1)],-31) == "<?php } # fine if (!\$framed) ?>") $linee_file[($num_linee_file - 1)] = substr($linee_file[($num_linee_file - 1)],0,-31);
$var_anno = "\$".mex("var_anno",$pag);
for ($num_va = 0 ; $num_va < $num_var_mod ; $num_va++) ${"var_".$var_mod[$num_va]} = "\$".mex("var_".$var_mod[$num_va],$pag);
$var_colore_tema = "\$".mex("var_colore_tema",$pag);
$var_valore_tema = "\$".mex("var_valore_tema",$pag);
if ($var_per_crea_mod == "SI") {
$var_tipo_db = "\$".mex("var_tipo_db",$pag);
$var_nome_db = "\$".mex("var_nome_db",$pag);
$var_computer_db = "\$".mex("var_computer_db",$pag);
$var_porta_db = "\$".mex("var_porta_db",$pag);
$var_utente_db = "\$".mex("var_utente_db",$pag);
$var_password_db = "\$".mex("var_password_db",$pag);
$var_carica_estensione_db = "\$".mex("var_carica_estensione_db",$pag);
$var_prefisso_tabelle_db = "\$".mex("var_prefisso_tabelle_db",$pag);
} # fine if ($var_per_crea_mod == "SI")
# FRASI
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) ${"var_".$fr_frase[$num_fr]} = "\$".mex("var_".$fr_frase[$num_fr],$pag);
$fine_variabili = "# ".mex("FINE VARIABILI MODIFICABILI",$pag);
global $num_periodi_date;

for ($num1 = 0 ; $num1 < $num_linee_file ; $num1++) {
$linea = togli_acapo($linee_file[$num1]);
unset($variabile);
if (substr($linea,0,strlen($var_anno)) == $var_anno) $variabile = "anno_modello_presente";
for ($num_va = 0 ; $num_va < $num_var_mod ; $num_va++) {
if (substr($linea,0,strlen(${"var_".$var_mod[$num_va]})) == ${"var_".$var_mod[$num_va]}) $variabile = $var_mod[$num_va];
} # fine for $num_va
$vlen = strlen($var_colore_tema."_");
if (substr($linea,0,$vlen) == $var_colore_tema."_") {
$variabile = "colore_tema_";
while (controlla_num_pos(substr($linea,$vlen,1)) == "SI") {
$variabile .= substr($linea,$vlen,1);
$vlen++;
} # fine while (controlla_num_pos(substr($linea,$vlen,1)) == "SI")
} # fine if (substr($linea,0,$vlen) == $var_colore_tema."_")
$vlen = strlen($var_valore_tema."_");
if (substr($linea,0,$vlen) == $var_valore_tema."_") {
$variabile = "valore_tema_";
while (controlla_num_pos(substr($linea,$vlen,1)) == "SI") {
$variabile .= substr($linea,$vlen,1);
$vlen++;
} # fine while (controlla_num_pos(substr($linea,$vlen,1)) == "SI")
} # fine if (substr($linea,0,$vlen) == $var_valore_tema."_")
if ($var_per_crea_mod == "SI") {
if (substr($linea,0,strlen($var_tipo_db)) == $var_tipo_db) $variabile = "tipo_db";
if (substr($linea,0,strlen($var_nome_db)) == $var_nome_db) $variabile = "nome_db";
if (substr($linea,0,strlen($var_computer_db)) == $var_computer_db) $variabile = "computer_db";
if (substr($linea,0,strlen($var_porta_db)) == $var_porta_db) $variabile = "porta_db";
if (substr($linea,0,strlen($var_utente_db)) == $var_utente_db) $variabile = "utente_db";
if (substr($linea,0,strlen($var_password_db)) == $var_password_db) $variabile = "password_db";
if (substr($linea,0,strlen($var_carica_estensione_db)) == $var_carica_estensione_db) $variabile = "carica_estensione_db";
if (substr($linea,0,strlen($var_prefisso_tabelle_db)) == $var_prefisso_tabelle_db) $variabile = "prefisso_tabelle_db";
} # fine if ($var_per_crea_mod == "SI")
# FRASI
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
$len = strlen(${"var_".$fr_frase[$num_fr]});
if (substr($linea,0,$len) == ${"var_".$fr_frase[$num_fr]} and (substr($linea,$len,1) == " " or substr($linea,$len,1) == "=")) $variabile = $fr_frase[$num_fr];
} # fine for $num_fr

if (!$num_periodi_date) {
if (substr($linea,0,strlen($var_periodi_menu)) == $var_periodi_menu) {
if (substr($linee_file[($num1 + 1)],0,16) == "<option value=\\\"") {
global $inizioperiodo0,$fineperiodo0,$intervalloperiodo0;
$inizioperiodo0 = explode("<option value=\\\"",$linea);
$inizioperiodo0 = explode("\\\">",$inizioperiodo0[1]);
$inizioperiodo0 = $inizioperiodo0[0];
if ($tipo_periodi == "s") $intervallo_base = 604800;
else $intervallo_base = 86400;
$data_prec = explode("-",$inizioperiodo0);
$data_corr = explode("-",substr($linee_file[($num1 + 1)],16,10));
$intervallo_prec = round(((mktime(0,0,0,$data_corr[1],$data_corr[2],$data_corr[0]) - mktime(0,0,0,$data_prec[1],$data_prec[2],$data_prec[0])) / $intervallo_base),0);
$intervalloperiodo0 = $intervallo_prec;
$num_periodi_date = 0;
while (substr($linee_file[($num1 + 1)],0,16) == "<option value=\\\"") {
$num1++;
$data_corr = explode("-",substr($linee_file[$num1],16,10));
$intervallo_corr = round(((mktime(0,0,0,$data_corr[1],$data_corr[2],$data_corr[0]) - mktime(0,0,0,$data_prec[1],$data_prec[2],$data_prec[0])) / $intervallo_base),0);
if ($intervallo_corr != $intervallo_prec) {
$data_succ= explode("-",substr($linee_file[($num1 + 1)],16,10));
$intervallo_succ = round(((mktime(0,0,0,$data_succ[1],$data_succ[2],$data_succ[0]) - mktime(0,0,0,$data_corr[1],$data_corr[2],$data_corr[0])) / $intervallo_base),0);
${"fineperiodo".$num_periodi_date} = $data_prec[0]."-".$data_prec[1]."-".$data_prec[2];
$num_periodi_date++;
global ${"inizioperiodo".$num_periodi_date},${"fineperiodo".$num_periodi_date},${"intervalloperiodo".$num_periodi_date};
${"inizioperiodo".$num_periodi_date} = $data_corr[0]."-".$data_corr[1]."-".$data_corr[2];
${"intervalloperiodo".$num_periodi_date} = $intervallo_succ;
$intervallo_prec = $intervallo_succ;
} # fine if ($intervallo_corr != $intervallo_prec)
$data_prec = $data_corr;
} # fine while (substr($linee_file[($num1 + 1)],0,strlen("<option value=\\\"")) == "<option value=\\\"")
${"fineperiodo".$num_periodi_date} = substr($linee_file[$num1],16,10);
$num_periodi_date++;
} # fine if (substr($linee_file[($num1 + 1)],0,16) == "<option value=\\\"")
} # fine if (substr($linea,0,strlen($var_periodi_menu)) == $var_periodi_menu)
} # fine if (!$num_periodi_date)

if (substr($linea,0,strlen($fine_variabili)) == $fine_variabili) break;

if ($variabile) {
global $$variabile;
$$variabile = explode("=",$linea);
$$variabile = trim(str_replace(${$variabile}[0]."=","",$linea));
if (substr($$variabile,-1) == ";") $$variabile = substr($$variabile,0,-1);
$$variabile = trim($$variabile);
if (substr($$variabile,0,1) == "\"" and substr($$variabile,-1) == "\"") $$variabile =  substr($$variabile,1,-1);
if (substr(str_replace(" ","",$$variabile),0,6) == "array(") {
$vett = $$variabile;
$$variabile = "";
${$variabile}['array_esistente'] = "SI";
$vett = preg_replace("/^array[ ]*\(/","",$vett);
if (substr($vett,-1) == ")") $vett = substr($vett,0,-1);
if (strcmp(trim($vett),"")) {
$vett = str_replace("\\\"","#@%&",str_replace("\\\\","#@%^",$vett)).",";
$in_apici = "NO";
unset($val_in_apici);
unset($val_non_apici);
for ($num2 = 0 ; $num2 < strlen($vett) ; $num2++) {
if (substr($vett,$num2,1) == "\"") {
if ($in_apici == "NO") $in_apici = "SI";
else $in_apici = "NO";
} # fine if (substr($vett,$num2,1) == "\"")
else {
if ($in_apici == "SI") $val_in_apici .= substr($vett,$num2,1);
else {
if (substr($vett,$num2,1) == ",") {
if ($val_in_apici) $val = $val_in_apici;
else $val = trim($val_non_apici);
${$variabile}[$key] = str_replace("#@%^","\\",str_replace("#@%&","\"",$val));
unset($val_in_apici);
unset($val_non_apici);
} # fine if (substr($vett,$num2,1) == ",")
else {
if (substr($vett,$num2,2) == "=>") {
if ($val_in_apici) $key = $val_in_apici;
else $key = trim($val_non_apici);
$key = str_replace("#@%^","\\",str_replace("#@%&","\"",$key));
$num2++;
unset($val_in_apici);
unset($val_non_apici);
} # fine if (substr($vett,$num2,2) == "=>")
else $val_non_apici .= substr($vett,$num2,1);
} # fine else if (substr($vett,$num2,1) == ",")
} # fine else if ($in_apici == "SI")
} # fine else if (substr($vett,$num2,1) == "\"")
} # fine for $num2
} # fine if (strcmp(trim($vett),""))
} # fine if (substr($$variabile,0,5) == "array")
else $$variabile = str_replace("\\\"","\"",$$variabile);
} # fine if ($variabile)

} # fine for $num1

$linee_file = implode("",$linee_file);
global $prima_parte_html,$ultima_parte_html;
$prima_parte_html = explode("<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file);
$prima_parte_html = $prima_parte_html[0];
if (strcmp(togli_acapo($prima_parte_html),"")) {
while (!strcmp(togli_acapo(substr($prima_parte_html,0,1)),"")) $prima_parte_html = substr($prima_parte_html,1);
while (!strcmp(togli_acapo(substr($prima_parte_html,-1)),"")) $prima_parte_html = substr($prima_parte_html,0,-1);
} # fine if (togli_acapo($prima_parte_html) != "")
$ultima_parte_html = explode("<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file);
$ultima_parte_html = explode("<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$ultima_parte_html[1]);
$ultima_parte_html = $ultima_parte_html[0];
if (togli_acapo($ultima_parte_html) != "") {
while (togli_acapo(substr($ultima_parte_html,0,1)) == "") $ultima_parte_html = substr($ultima_parte_html,1);
while (togli_acapo(substr($ultima_parte_html,-1)) == "") $ultima_parte_html = substr($ultima_parte_html,0,-1);
} # fine if (togli_acapo($ultima_parte_html) != "")


if ($var_per_crea_mod == "SI") {
if (!$anno_modello) $anno_modello = $anno_modello_presente;
$tableanni = $PHPR_TAB_PRE."anni";
if (controlla_anno($anno_modello) != "SI") {
$continua = "NO";
$anno_modello = "";
} # fine if (controlla_anno($anno_modello) != "SI")
else {
$anno_esistente = esegui_query("select * from $tableanni where idanni = '$anno_modello'");
if (numlin_query($anno_esistente) != 1) $continua = "NO";
} # fine else if (controlla_anno($anno_modello) != "SI")
if ($continua != "NO") {

$SI = mex("SI",$pag);
$NO = mex("NO",$pag);
global $M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$m_stile_soldi,$m_stile_data,$m_valuta_sing,$m_valuta_plur,$utente_lis;
if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
$M_PHPR_DB_TYPE = $tipo_db;
$M_PHPR_DB_NAME = $nome_db;
$M_PHPR_DB_HOST = $computer_db;
$M_PHPR_DB_PORT = $porta_db;
$M_PHPR_DB_USER = $utente_db;
$M_PHPR_DB_PASS = $password_db;
if (strtoupper($carica_estensione_db) == $SI) $carica_estensione_db = "SI";
else $carica_estensione_db = "NO";
$M_PHPR_LOAD_EXT = $carica_estensione_db;
$M_PHPR_TAB_PRE = $prefisso_tabelle_db;
$m_stile_soldi = $stile_soldi;
$m_stile_data = $stile_data;
$m_valuta_sing = $fr_Valuta_sing;
$m_valuta_plur = $fr_Valuta_plur;
if (strtoupper($anteponi_nome_valuta) == $SI) $anteponi_nome_valuta = "SI";
else $anteponi_nome_valuta = "NO";
$utente_lis = $utente_liste;

if (strtoupper($estendi_ultima_data) == $SI) $estendi_ultima_data = "SI";
else $estendi_ultima_data = "NO";
global $sett_no_prenota;
$sett_no_prenota = $periodi_no_richieste;
if ((string) $sett_no_prenota == "") $sett_no_prenota = 0;
$tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
$rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
$tariffa = "tariffa".$numtariffa;
$nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
global $$tariffa,$$nome_tariffa_imposto;
$$tariffa = "";
$$nome_tariffa_imposto = "";
if (strtoupper($tariffe_mostra[$numtariffa]) == $SI) $$tariffa = "SI";
$$nome_tariffa_imposto = $nomi_tariffe_imposte[$numtariffa];
} # fine for $numtariffa
global $chiedi_num_app_tipologia,$max_num_app_tipologia,$parola_appartamento,$parola_appartamenti;
if (strtoupper($chiedi_numero_appartamenti_per_tipologia) == $SI) $chiedi_num_app_tipologia = "SI";
else $chiedi_num_app_tipologia = "NO";
$max_num_app_tipologia = $massimo_numero_appartamenti_per_tipologia;
$parola_appartamenti = $fr_appartamenti;
$parola_appartamento = $fr_appartamento;
global $aggiungi_tipologie,$max_num_tipologie,$cerca_app_vicini;
if (strtoupper($aggiungi_altre_tipologie) == $SI) $aggiungi_tipologie = "SI";
else $aggiungi_tipologie = "NO";
$max_num_tipologie = $massimo_numero_altre_tipologie;
if (strtoupper($cerca_appartamenti_vicini) == $SI) $cerca_app_vicini = "SI";
if (strtoupper($cerca_appartamenti_vicini) == $NO) $cerca_app_vicini = "NO";
if (strtoupper($cerca_appartamenti_vicini) == strtoupper(mex("se possibile",$pag))) $cerca_app_vicini = "se possibile";
if (strtoupper($cerca_appartamenti_vicini) == strtoupper(mex("chiedere",$pag))) $cerca_app_vicini = "chiedere";
global $chiedi_num_persone,$max_num_persone,$max_num_aggiungi_letti;
if (strtoupper($chiedi_numero_persone) == $SI) $chiedi_num_persone = "SI";
else $chiedi_num_persone = "NO";
$max_num_persone = $massimo_numero_persone;
$max_num_aggiungi_letti = $massimo_numero_letti_aggiuntivi;
global $mostra_costi_aggiuntivi,$num_colonne_costi_agg;
if (strtoupper($chiedi_costi_aggiuntivi_di_pag_inserzione) == $SI) $mostra_costi_aggiuntivi = "SI";
else $mostra_costi_aggiuntivi = "NO";
$num_colonne_costi_agg = $numero_colonne_costi_aggiuntivi;
if (strtoupper($aggiungi_costi_fissi) == $SI) $aggiungi_costi_fissi = "SI";
if (strtoupper($aggiungi_costi_fissi) == $NO) $aggiungi_costi_fissi = "NO";
if ($aggiungi_costi_fissi != "SI" and $aggiungi_costi_fissi != "NO") $aggiungi_costi_fissi = "opzionale";
$dati_ca = dati_costi_agg_ntariffe($tablenometariffe_modello,"NO");
for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
$attiva_costo = "attiva_costo".$dati_ca[$numca]['id'];
$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
$nome_cat_imp = "nome_cat_imp".$dati_ca[$numca]['id'];
global $$attiva_costo,$$nome_costo_imposto,$$nome_cat_imp;
$$attiva_costo = "";
if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $$attiva_costo = "SI";
$$nome_costo_imposto = $nomi_costi_agg_imposti[$dati_ca[$numca]['id']];
if ($dati_ca[$numca]['combina'] == "s") $$nome_cat_imp = $categorie_costi_agg_imposte[$dati_ca[$numca]['categoria']];
} # fine for $numca

global $num_codici_promo;
if ($campi_codici_promo['array_esistente']) $num_codici_promo = (count($campi_codici_promo) - 1);
else $num_codici_promo = 0;
for ($num1 = 1 ; $num1 <= $num_codici_promo ; $num1++) {
global ${"codice_promo".$num1},${"tipo_codice_promo".$num1},${"costo_codice_promo".$num1};
${"codice_promo".$num1} = $campi_codici_promo[$num1];
${"tipo_codice_promo".$num1} = substr($costi_campi_codici_promo[$num1],0,1);
${"costo_codice_promo".$num1} = substr($costi_campi_codici_promo[$num1],1);
if (${"tipo_codice_promo".$num1} != "-") ${"tipo_codice_promo".$num1} = "+";
if (@get_magic_quotes_gpc()) ${"codice_promo".$num1} = addslashes(${"codice_promo".$num1});
} # fine for $num1

global $frase_alternativa_regola1,$num_motivazioni;
$tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) order by app_agenzia");
$num_regole = numlin_query($regole);
$motivazioni_presenti = array();
$num_motivazioni = 0;
for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
$idregole = risul_query($regole,$num1,'idregole');
$motivazione = risul_query($regole,$num1,'motivazione');
if (!$motivazione) $motivazione = " ";
if ($motivazioni_presenti[$motivazione] != "SI") {
$motivazioni_presenti[$motivazione] = "SI";
$var_motivazione = "var_mot_".$num_motivazioni;
$num_motivazioni++;
global $$var_motivazione;
$$var_motivazione = "";
if (strtoupper($considera_motivazioni_regola1[$motivazione]) == $SI) $$var_motivazione = $motivazione;
} # fine if ($motivazioni_presenti[$motivazione] != "SI")
} # fine for $num1
if (strtoupper($mostra_frase_alternativa_regola1) == $SI) $mostra_frase_alternativa_regola1 = "SI";
else $mostra_frase_alternativa_regola1 = "NO";
$frase_alternativa_regola1 = $fr_alternativa_regola1;
if (strtoupper($mostra_caparra) == $SI) $mostra_caparra = "SI";
else $mostra_caparra = "NO";
if (strtoupper($mostra_giorni_pieni) == $SI) $mostra_giorni_pieni = "SI";
else $mostra_giorni_pieni = "NO";
if (strtoupper($mostra_bottone_paypal) == $SI) $mostra_bottone_paypal = "SI";
else $mostra_bottone_paypal = "NO";

global $ind_email,$utente_mess,$orig_prenota;
if ($utente_messaggio == mex("tutti",$pag)) $utente_messaggio = "tutti";
$ind_email = $indirizzo_email;
$utente_mess = $utente_messaggio;
$orig_prenota = $origine_prenotazione;

global $maschera_envelope;
if (strtoupper($mostra_richiesta_via_mail) == $SI) $mostra_richiesta_via_mail = "SI";
else $mostra_richiesta_via_mail = "NO";
if (strtoupper($manda_copia_richiesta_email) == $SI) $manda_copia_richiesta_email = "SI";
else $manda_copia_richiesta_email = "NO";
if (strtoupper($maschera_email) == $SI) $maschera_envelope = "SI";
else $maschera_envelope = "NO";
$chiedi_cognome = strtoupper($chiedi_cognome);
if ($chiedi_cognome != $SI and $chiedi_cognome != $NO) $chiedi_cognome = "opzionale";
if ($chiedi_cognome == $SI) $chiedi_cognome = "SI";
if ($chiedi_cognome == $NO) $chiedi_cognome = "NO";
$chiedi_nome = strtoupper($chiedi_nome);
if ($chiedi_nome != $SI and $chiedi_nome != $NO) $chiedi_nome = "opzionale";
if ($chiedi_nome == $SI) $chiedi_nome = "SI";
if ($chiedi_nome == $NO) $chiedi_nome = "NO";
$chiedi_email = strtoupper($chiedi_email);
if ($chiedi_email != $SI and $chiedi_email != $NO) $chiedi_email = "opzionale";
if ($chiedi_email == $SI) $chiedi_email = "SI";
if ($chiedi_email == $NO) $chiedi_email = "NO";
$chiedi_sesso = strtoupper($chiedi_sesso);
if ($chiedi_sesso != $SI and $chiedi_sesso != $NO) $chiedi_sesso = "opzionale";
if ($chiedi_sesso == $SI) $chiedi_sesso = "SI";
if ($chiedi_sesso == $NO) $chiedi_sesso = "NO";
$chiedi_datanascita = strtoupper($chiedi_datanascita);
if ($chiedi_datanascita != $SI and $chiedi_datanascita != $NO) $chiedi_datanascita = "opzionale";
if ($chiedi_datanascita == $SI) $chiedi_datanascita = "SI";
if ($chiedi_datanascita == $NO) $chiedi_datanascita = "NO";
$chiedi_documento = strtoupper($chiedi_documento);
if ($chiedi_documento != $SI and $chiedi_documento != $NO) $chiedi_documento = "opzionale";
if ($chiedi_documento == $SI) $chiedi_documento = "SI";
if ($chiedi_documento == $NO) $chiedi_documento = "NO";
$chiedi_nazione = strtoupper($chiedi_nazione);
if ($chiedi_nazione != $SI and $chiedi_nazione != $NO) $chiedi_nazione = "opzionale";
if ($chiedi_nazione == $SI) $chiedi_nazione = "SI";
if ($chiedi_nazione == $NO) $chiedi_nazione = "NO";
$chiedi_citta = strtoupper($chiedi_citta);
if ($chiedi_citta != $SI and $chiedi_citta != $NO) $chiedi_citta = "opzionale";
if ($chiedi_citta == $SI) $chiedi_citta = "SI";
if ($chiedi_citta == $NO) $chiedi_citta = "NO";
$chiedi_regione = strtoupper($chiedi_regione);
if ($chiedi_regione != $SI and $chiedi_regione != $NO) $chiedi_regione = "opzionale";
if ($chiedi_regione == $SI) $chiedi_regione = "SI";
if ($chiedi_regione == $NO) $chiedi_regione = "NO";
$chiedi_via = strtoupper($chiedi_via);
if ($chiedi_via != $SI and $chiedi_via != $NO) $chiedi_via = "opzionale";
if ($chiedi_via == $SI) $chiedi_via = "SI";
if ($chiedi_via == $NO) $chiedi_via = "NO";
$chiedi_numcivico = strtoupper($chiedi_numcivico);
if ($chiedi_numcivico != $SI and $chiedi_numcivico != $NO) $chiedi_numcivico = "opzionale";
if ($chiedi_numcivico == $SI) $chiedi_numcivico = "SI";
if ($chiedi_numcivico == $NO) $chiedi_numcivico = "NO";
$chiedi_cap = strtoupper($chiedi_cap);
if ($chiedi_cap != $SI and $chiedi_cap != $NO) $chiedi_cap = "opzionale";
if ($chiedi_cap == $SI) $chiedi_cap = "SI";
if ($chiedi_cap == $NO) $chiedi_cap = "NO";
$chiedi_telefono = strtoupper($chiedi_telefono);
if ($chiedi_telefono != $SI and $chiedi_telefono != $NO) $chiedi_telefono = "opzionale";
if ($chiedi_telefono == $SI) $chiedi_telefono = "SI";
if ($chiedi_telefono == $NO) $chiedi_telefono = "NO";
$chiedi_telefono2 = strtoupper($chiedi_telefono2);
if ($chiedi_telefono2 != $SI and $chiedi_telefono2 != $NO) $chiedi_telefono2 = "opzionale";
if ($chiedi_telefono2 == $SI) $chiedi_telefono2 = "SI";
if ($chiedi_telefono2 == $NO) $chiedi_telefono2 = "NO";
$chiedi_telefono3 = strtoupper($chiedi_telefono3);
if ($chiedi_telefono3 != $SI and $chiedi_telefono3 != $NO) $chiedi_telefono3 = "opzionale";
if ($chiedi_telefono3 == $SI) $chiedi_telefono3 = "SI";
if ($chiedi_telefono3 == $NO) $chiedi_telefono3 = "NO";
$chiedi_fax = strtoupper($chiedi_fax);
if ($chiedi_fax != $SI and $chiedi_fax != $NO) $chiedi_fax = "opzionale";
if ($chiedi_fax == $SI) $chiedi_fax = "SI";
if ($chiedi_fax == $NO) $chiedi_fax = "NO";
$chiedi_codfiscale = strtoupper($chiedi_codfiscale);
if (!$chiedi_codfiscale) $chiedi_codfiscale = $NO;
if ($chiedi_codfiscale != $SI and $chiedi_codfiscale != $NO) $chiedi_codfiscale = "opzionale";
if ($chiedi_codfiscale == $SI) $chiedi_codfiscale = "SI";
if ($chiedi_codfiscale == $NO) $chiedi_codfiscale = "NO";
$chiedi_partitaiva = strtoupper($chiedi_partitaiva);
if (!$chiedi_partitaiva) $chiedi_partitaiva = $NO;
if ($chiedi_partitaiva != $SI and $chiedi_partitaiva != $NO) $chiedi_partitaiva = "opzionale";
if ($chiedi_partitaiva == $SI) $chiedi_partitaiva = "SI";
if ($chiedi_partitaiva == $NO) $chiedi_partitaiva = "NO";
$chiedi_commento = strtoupper($chiedi_commento);
if ($chiedi_commento != $SI and $chiedi_commento != $NO) $chiedi_commento = "opzionale";
if ($chiedi_commento == $SI) $chiedi_commento = "SI";
if ($chiedi_commento == $NO) $chiedi_commento = "NO";
$chiedi_oracheckin = strtoupper($chiedi_oracheckin);
if ($chiedi_oracheckin != $SI and $chiedi_oracheckin != $NO) $chiedi_oracheckin = "opzionale";
if ($chiedi_oracheckin == $SI) $chiedi_oracheckin = "SI";
if ($chiedi_oracheckin == $NO) $chiedi_oracheckin = "NO";
$chiedi_metodopagamento = strtoupper($chiedi_metodopagamento);
if ($chiedi_metodopagamento != $SI and $chiedi_metodopagamento != $NO) $chiedi_metodopagamento = "opzionale";
if ($chiedi_metodopagamento == $SI) $chiedi_metodopagamento = "SI";
if ($chiedi_metodopagamento == $NO) $chiedi_metodopagamento = "NO";
$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
$metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '1'");
$metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
global $num_metodi_pagamento;
$num_metodi_pagamento = 0;
if ($metodi_pagamento) {
$metodi_pagamento = explode(",",$metodi_pagamento);
$num_metodi_pagamento = count($metodi_pagamento);
for ($num1 = 0 ; $num1 < $num_metodi_pagamento ; $num1++) {
$metodo = $metodi_pagamento[$num1];
global ${"var_met_paga_".$num1},${"nome_met_paga_imposto_".$num1};
if (strtoupper($metodi_pagamento_da_chiedere[$metodo]) == $SI) ${"var_met_paga_".$num1} = $metodo;
else ${"var_met_paga_".$num1} = "";
if (@get_magic_quotes_gpc()) ${"var_met_paga_".$num1} = addslashes(${"var_met_paga_".$num1});
if ($nomi_metodi_pagamento_imposti[$metodo]) ${"nome_met_paga_imposto_".$num1} = $nomi_metodi_pagamento_imposti[$metodo];
else ${"nome_met_paga_imposto_".$num1} = "";
if (@get_magic_quotes_gpc()) ${"nome_met_paga_imposto_".$num1} = addslashes(${"nome_met_paga_imposto_".$num1});
} # fine for $num1
} # fine if ($metodi_pagamento)

global $num_campi_pers;
if ($campi_form_personalizzati['array_esistente']) $num_campi_pers = (count($campi_form_personalizzati) - 1);
else $num_campi_pers = 0;
for ($num1 = 1 ; $num1 <= $num_campi_pers ; $num1++) {
global ${"campo_pers".$num1},${"chiedi_campo_pers".$num1},${"ins_campo_pers".$num1};
${"campo_pers".$num1} = $campi_form_personalizzati[$num1];
${"chiedi_campo_pers".$num1} = $chiedi_campi_form_personalizzati[$num1];
${"ins_campo_pers".$num1} = $ins_campi_form_personalizzati[$num1];
if (${"chiedi_campo_pers".$num1} == $SI) ${"chiedi_campo_pers".$num1} = "SI";
else ${"chiedi_campo_pers".$num1} = "opzionale";
if (@get_magic_quotes_gpc()) ${"campo_pers".$num1} = addslashes(${"campo_pers".$num1});
} # fine for $num1

global $num_campi_doc_cond;
if ($campi_form_doc_condizioni['array_esistente']) $num_campi_doc_cond = (count($campi_form_doc_condizioni) - 1);
else $num_campi_doc_cond = 0;
for ($num1 = 1 ; $num1 <= $num_campi_doc_cond ; $num1++) {
global ${"num_doc_cond".$num1},${"chiedi_num_doc_cond".$num1};
${"num_doc_cond".$num1} = $campi_form_doc_condizioni[$num1];
${"chiedi_num_doc_cond".$num1} = $chiedi_campi_form_doc_condizioni[$num1];
if (${"chiedi_num_doc_cond".$num1} == $SI) ${"chiedi_num_doc_cond".$num1} = "SI";
elseif (substr(${"chiedi_num_doc_cond".$num1},0,3) != "op_") ${"chiedi_num_doc_cond".$num1} = "opzionale";
} # fine for $num1

global $mostra_quadro_disp;
$mostra_quadro_disp = "";
if (strtoupper($mostra_quadro_disponibilita) == $SI) $mostra_quadro_disp = "SI";
if (strtoupper($raggruppa_quadro_disponibilita_con_persone) == $SI) $mostra_quadro_disp = "pers";
if (strtoupper($raggruppa_quadro_disponibilita_con_regola_2) == $SI) $mostra_quadro_disp = "reg2";
if (strtoupper($mostra_numero_liberi_quadro_disponibilita) == $SI) $mostra_numero_liberi_quadro_disponibilita = "SI";
else $mostra_numero_liberi_quadro_disponibilita = "NO";
if (strtoupper($mostra_calendario_scelta_date) == $SI) $mostra_calendario_scelta_date = "SI";
else $mostra_calendario_scelta_date = "NO";
if (strtoupper($allinea_disponibilita_con_arrivo) == $SI) $allinea_disponibilita_con_arrivo = "SI";
else $allinea_disponibilita_con_arrivo = "NO";
if (strtoupper($apri_nuova_finestra_da_frame) == $SI) $apri_nuova_finestra_da_frame = "SI";
else $apri_nuova_finestra_da_frame = "NO";

if (get_magic_quotes_gpc()) {
$prima_parte_html = addslashes($prima_parte_html);
$ultima_parte_html = addslashes($ultima_parte_html);
} # fine if (get_magic_quotes_gpc())

} # fine if ($continua != "NO")
} # fine if ($var_per_crea_mod == "SI")


} # fine function recupera_var_modello_disponibilita







function crea_modello_disponibilita ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi) {
global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$max_num_app_tipologia,$chiedi_num_app_tipologia,$parola_appartamenti,$parola_appartamento,$aggiungi_tipologie,$max_num_tipologie,$cerca_app_vicini,$chiedi_num_persone,$max_num_persone,$costo_aggiungi_letti,$max_num_aggiungi_letti,$sett_no_prenota;
global $mostra_richiesta_via_mail,$mostra_costi_aggiuntivi,$num_colonne_costi_agg,$num_motivazioni,$mostra_quadro_disp,$mostra_numero_liberi_quadro_disponibilita,$allinea_disponibilita_con_arrivo,$m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$utente_lis,$aggiungi_costi_fissi,$assegna_con_regola2,$mostra_frase_alternativa_regola1,$mostra_caparra,$ind_email,$maschera_envelope,$manda_copia_richiesta_email;
global $colore_sfondo_quadro_disponibilita,$colore_inizio_settimana_quadro_disponibilita,$colore_libero_quadro_disponibilita,$colore_occupato_quadro_disponibilita,$apertura_font_quadro_disponibilita,$chiusura_font_quadro_disponibilita,$apertura_tag_font,$chiusura_tag_font,$apertura_tag_font_rosse,$chiusura_tag_font_rosse,$stile_tabella_prenotazione,$m_valuta_sing,$m_valuta_plur,$frase_alternativa_regola1,$cambia_frasi,$utente_mess;
global $orig_prenota,$num_metodi_pagamento,$num_campi_pers,$num_campi_doc_cond,$chiedi_cognome,$chiedi_nome,$chiedi_email,$chiedi_sesso,$chiedi_datanascita,$chiedi_documento,$chiedi_nazione,$chiedi_citta,$chiedi_regione,$chiedi_via,$chiedi_numcivico,$chiedi_cap,$chiedi_telefono,$chiedi_telefono2,$chiedi_telefono3,$chiedi_fax,$chiedi_codfiscale,$chiedi_partitaiva,$chiedi_commento,$chiedi_oracheckin,$chiedi_metodopagamento;
global $mostra_bottone_paypal,$nome_modello_paypal,$mostra_calendario_scelta_date,$stile_riquadro_calendario,$stile_tabella_calendario,$stile_bottoni_calendario,$stile_bottone_apertura_calendario,$spostamento_orizzontale_calendario,$colore_data_attiva_calendario,$colore_data_selezionata_calendario,$prima_parte_html,$ultima_parte_html,$mostra_giorni_pieni,$modello_esistente;
global $file_css_frame,$apri_nuova_finestra_da_frame,$altezza_finestra_da_frame,$larghezza_finestra_da_frame,$tema_modello,$num_codici_promo;
$tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
$tableperiodi_modello = $PHPR_TAB_PRE."periodi".$anno_modello;
$tableanni = $PHPR_TAB_PRE."anni";
$tableutenti = $PHPR_TAB_PRE."utenti";
$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
$tablecontratti = $PHPR_TAB_PRE."contratti";

if (controlla_anno($anno_modello) != "SI") {
$continua = "NO";
$anno_modello = "";
} # fine if (controlla_anno($anno_modello) != "SI")
else {
$anno_esistente = esegui_query("select * from $tableanni where idanni = '$anno_modello'");
if (numlin_query($anno_esistente) != 1) $continua = "NO";
} # fine else if (controlla_anno($anno_modello) != "SI")
if ($continua != "NO") {

if ($estendi_ultima_data != "SI") $estendi_ultima_data = "NO";

$date_in_menu = "";
$idfineperiodo_prec = -10;
if (!$num_periodi_date or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
global ${"inizioperiodo".$num1},${"fineperiodo".$num1},${"intervalloperiodo".$num1};
$inizioperiodo = aggslashdb(${"inizioperiodo".$num1});
$fineperiodo = aggslashdb(${"fineperiodo".$num1});
$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi_modello where datainizio = '$inizioperiodo' ");
$num_idinizioperiodo = numlin_query($idinizioperiodo);
if ($num_idinizioperiodo == 0) { $idinizioperiodo = 10000; }
else { $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi'); }
$inizioperiodo = $idinizioperiodo;
if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1)) {
$idfineperiodo = esegui_query("select max(idperiodi) from $tableperiodi_modello");
$idfineperiodo = risul_query($idfineperiodo,0,0);
} # fine if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1))
else {
$idfineperiodo = esegui_query("select idperiodi from $tableperiodi_modello where datafine = '$fineperiodo' ");
$num_idfineperiodo = numlin_query($idfineperiodo);
if ($num_idfineperiodo == 0) { $idfineperiodo = -1; }
else { $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi'); }
} # fine else if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1))
$fineperiodo = $idfineperiodo;
${"inizioperiodo".$num1} = $inizioperiodo;
${"fineperiodo".$num1} = $fineperiodo;
if ($idfineperiodo < $idinizioperiodo) $continua = "NO";
if (($idfineperiodo_prec + 1) >= $idinizioperiodo) $continua = "NO";
$idfineperiodo_prec = $idfineperiodo;
${"intervalloperiodo".$num1} = aggslashdb(${"intervalloperiodo".$num1});
if (!${"intervalloperiodo".$num1} or controlla_num_pos(${"intervalloperiodo".$num1}) == "NO" or ${"intervalloperiodo".$num1} > 99) $continua = "NO";
} # fine for $num1
if ($continua == "NO") {
if ($silenzio == "NO") echo mex("Le date sono sbagliate",$pag).". <br>";
} # fine if ($continua == "NO")
else {
$file_intero = file(C_DATI_PATH."/selectperiodi$anno_modello.1.php");
$num_linee_file_intero = count($file_intero);
$pag_gm = "giorni_mesi.php";
$m_tipo_periodi = esegui_query("select tipo_periodi from $tableanni where idanni = '$anno_modello'");
$m_tipo_periodi = risul_query($m_tipo_periodi,0,0);
for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
$inizioperiodo = ${"inizioperiodo".$num1};
$fineperiodo = ${"fineperiodo".$num1};
$num_intervallo = 1;
for ($num2 = 0 ; $num2 < $num_linee_file_intero ; $num2++) {
if (substr($file_intero[$num2],0,7) == "<option") {
$data_option = substr($file_intero[$num2],16,10);
$id_data_option = esegui_query("select idperiodi from $tableperiodi_modello where datainizio = '$data_option' ");
$esiste_data_option = numlin_query($id_data_option);
if ($esiste_data_option == 1) $id_data_option = risul_query($id_data_option,0,'idperiodi');
else {
$id_data_option = esegui_query("select idperiodi from $tableperiodi_modello where datafine = '$data_option' ");
$id_data_option = risul_query($id_data_option,0,'idperiodi');
} # fine else if ($esiste_data_option == 1)
if ($id_data_option >= $inizioperiodo and $id_data_option <= ($fineperiodo + 1)) {
if ($num_intervallo == 1) {
$giorno_option = substr($data_option,8,2);
$mese_option = substr($data_option,5,2);
$anno_option = substr($data_option,0,4);
$nome_giorno = date("D" , mktime(0,0,0,$mese_option,$giorno_option,$anno_option));
$nome_mese = date("M" , mktime(0,0,0,$mese_option,$giorno_option,$anno_option));
if ($m_tipo_periodi == "g") {
if ($nome_giorno == "Sun") $nome_giorno = mex2(" Do",$pag_gm,$lingua_modello);
if ($nome_giorno == "Mon") $nome_giorno = mex2(" Lu",$pag_gm,$lingua_modello);
if ($nome_giorno == "Tue") $nome_giorno = mex2(" Ma",$pag_gm,$lingua_modello);
if ($nome_giorno == "Wed") $nome_giorno = mex2(" Me",$pag_gm,$lingua_modello);
if ($nome_giorno == "Thu") $nome_giorno = mex2(" Gi",$pag_gm,$lingua_modello);
if ($nome_giorno == "Fri") $nome_giorno = mex2(" Ve",$pag_gm,$lingua_modello);
if ($nome_giorno == "Sat") $nome_giorno = mex2(" Sa",$pag_gm,$lingua_modello);
} # fine if ($m_tipo_periodi == "g")
else $nome_giorno = "";
if ($nome_mese == "Jan") $nome_mese = mex2("Gen",$pag_gm,$lingua_modello);
if ($nome_mese == "Feb") $nome_mese = mex2("Feb",$pag_gm,$lingua_modello);
if ($nome_mese == "Mar") $nome_mese = mex2("Mar",$pag_gm,$lingua_modello);
if ($nome_mese == "Apr") $nome_mese = mex2("Apr",$pag_gm,$lingua_modello);
if ($nome_mese == "May") $nome_mese = mex2("Mag",$pag_gm,$lingua_modello);
if ($nome_mese == "Jun") $nome_mese = mex2("Giu",$pag_gm,$lingua_modello);
if ($nome_mese == "Jul") $nome_mese = mex2("Lug",$pag_gm,$lingua_modello);
if ($nome_mese == "Aug") $nome_mese = mex2("Ago",$pag_gm,$lingua_modello);
if ($nome_mese == "Sep") $nome_mese = mex2("Set",$pag_gm,$lingua_modello);
if ($nome_mese == "Oct") $nome_mese = mex2("Ott",$pag_gm,$lingua_modello);
if ($nome_mese == "Nov") $nome_mese = mex2("Nov",$pag_gm,$lingua_modello);
if ($nome_mese == "Dec") $nome_mese = mex2("Dic",$pag_gm,$lingua_modello);
$date_in_menu .= "<option value=\\\"$data_option\\\">$nome_mese $giorno_option$nome_giorno, $anno_option</option>
";
} # fine if ($num_intervallo == 1)
if ($num_intervallo == ${"intervalloperiodo".$num1}) $num_intervallo = 1;
else $num_intervallo++;
} # fine if ($id_data_option > $inizioperiodo and...
} # fine if (substr($file_intero[$num2],0,7) == "<option")
} # fine for $num2
} # fine for $num1

$d_names = "\\\"". mex2(" Do",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Lu",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Ma",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Me",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Gi",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Ve",$pag_gm,$lingua_modello)."\\\",\\\"". mex2(" Sa",$pag_gm,$lingua_modello)."\\\"";
$m_names = "\\\"". mex2("Gen",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Feb",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Mar",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Apr",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Mag",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Giu",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Lug",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Ago",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Set",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Ott",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Nov",$pag_gm,$lingua_modello)."\\\",\\\"". mex2("Dic",$pag_gm,$lingua_modello)."\\\"";

} # fine else if ($continua == "NO")

if (controlla_num_pos($sett_no_prenota) == "NO" or $sett_no_prenota < 0 or $sett_no_prenota > 365) {
$continua = "NO";
global $parola_settimane;
if ($silenzio == "NO") echo mex("Numero di $parola_settimane dopo cui prendere richieste errato",$pag).".<br>";
} # fine if (controlla_num_pos($sett_no_prenota) == "NO" or $sett_no_prenota < 1 or $sett_no_prenota > 365)

$utente_liste = $utente_lis;
if (@get_magic_quotes_gpc()) $utente_liste = stripslashes($utente_liste);
$utente_esistente = esegui_query("select idutenti from $tableutenti where nome_utente = '".aggslashdb($utente_liste)."'");
if (numlin_query($utente_esistente) != 1) {
$utente_liste = esegui_query("select nome_utente from $tableutenti where idutenti = '1'");
$utente_liste = risul_query($utente_liste,0,'nome_utente');
} # fine if (numlin_query($utente_esistente) != 1)

if ($chiedi_num_app_tipologia != "SI") $chiedi_num_app_tipologia = "NO";
if ($chiedi_num_app_tipologia == "SI" and controlla_num_pos($max_num_app_tipologia) == "NO") {
$continua = "NO";
if ($silenzio == "NO") echo mex("Numero massimo di appartamenti per tipologia errato",'unit.php').".<br>";
} # fine if ($chiedi_num_app_tipologia == "SI" and controlla_num_pos($max_num_app_tipologia) == "NO")
if ($chiedi_num_app_tipologia == "NO" and controlla_num_pos($max_num_app_tipologia) == "NO") $max_num_app_tipologia = 0;

if ($chiedi_num_app_tipologia == "SI" and !$parola_appartamenti) {
$continua = "NO";
if ($silenzio == "NO") echo mex("Si deve inserire la parola per indicare gli appartamenti",'unit.php').".<br>";
} # fine if ($chiedi_num_app_tipologia == "SI" and !$parola_appartamenti)
if ($chiedi_num_app_tipologia != "SI" and !$parola_appartamento) $parola_appartamento = mex2("appartamento",'unit.php',$lingua_modello);
if ($chiedi_num_app_tipologia != "SI" and !$parola_appartamenti) $parola_appartamenti = mex2("appartamenti",'unit.php',$lingua_modello);

if ($aggiungi_tipologie != "SI") $aggiungi_tipologie = "NO";
if ($aggiungi_tipologie == "SI" and (controlla_num_pos($max_num_tipologie) == "NO" or $max_num_tipologie == 0)) {
$continua = "NO";
if ($silenzio == "NO") echo mex("Numero massimo di tipologie errato",$pag).".<br>";
} # fine if ($aggiungi_tipologie == "SI" and controlla_num_pos($max_num_tipologie) == "NO" and $max_num_tipologie != 0)
if ($aggiungi_tipologie != "SI" and (controlla_num_pos($max_num_tipologie) == "NO" or $max_num_tipologie == 0)) $max_num_tipologie = 3;
if ($cerca_app_vicini != "SI" and $cerca_app_vicini != "se possibile" and $cerca_app_vicini != "chiedere") $cerca_app_vicini = "NO";

if ($chiedi_num_persone == "SI" and controlla_num_pos($max_num_persone) == "NO") {
$continua = "NO";
if ($silenzio == "NO") echo mex("Numero massimo di persone errato",$pag).".<br>";
} # fine if ($chiedi_num_persone == "SI" and controlla_num_pos($max_num_persone) == "NO")
if ($chiedi_num_persone != "SI" and controlla_num_pos($max_num_persone) == "NO") $max_num_persone = 0;

$rigatariffe = esegui_query("select * from $tablenometariffe_modello where idntariffe = 1 ");
$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
$dati_ca = dati_costi_agg_ntariffe($tablenometariffe_modello,$numero_tariffe);
if ($chiedi_num_persone != "SI") $costo_aggiungi_letti = "";
if ($costo_aggiungi_letti != "" and ($dati_ca[$dati_ca['id'][$costo_aggiungi_letti]]['letto'] != "s" or $dati_ca[$dati_ca['id'][$costo_aggiungi_letti]]['numsett'] == "c" or $dati_ca[$dati_ca['id'][$costo_aggiungi_letti]]['mostra'] != "s" or $dati_ca[$costo_aggiungi_letti]['combina'] == "s")) $continua = "NO";

if ($chiedi_num_persone == "SI" and $costo_aggiungi_letti != "" and (controlla_num_pos($max_num_aggiungi_letti) == "NO" or $max_num_aggiungi_letti == 0)) {
$continua = "NO";
if ($silenzio == "NO") echo mex("Numero massimo di letti aggiuntivi errato",$pag).".<br>";
} # fine if ($chiedi_num_persone == "SI" and $costo_aggiungi_letti != "" and...
if (($chiedi_num_persone != "SI" or $costo_aggiungi_letti == "") and (controlla_num_pos($max_num_aggiungi_letti) == "NO" or $max_num_aggiungi_letti == 0)) $max_num_aggiungi_letti = 2;

if ($mostra_costi_aggiuntivi == "SI" and (controlla_num_pos($num_colonne_costi_agg) == "NO" or $num_colonne_costi_agg == 0)) {
$continua = "NO";
if ($silenzio == "NO") echo mex("Numero di colonne dei costi aggiuntivi errato",$pag).".<br>";
} # fine if ($mostra_costi_aggiuntivi == "SI" and (controlla_num_pos($num_colonne_costi_agg) == "NO" or $num_colonne_costi_agg == 0))
if ($mostra_costi_aggiuntivi != "SI" and (controlla_num_pos($num_colonne_costi_agg) == "NO" or $num_colonne_costi_agg == 0)) $num_colonne_costi_agg = 2;

if (str_replace("..","",$nome_modello_paypal) != $nome_modello_paypal) $nome_modello_paypal = "";
if (str_replace("/","",$nome_modello_paypal) != $nome_modello_paypal) $nome_modello_paypal = "";
if ($mostra_bottone_paypal != "SI") $nome_modello_paypal = "";
if (!$nome_modello_paypal) $mostra_bottone_paypal = "NO";

$indirizzo_email = $ind_email;
$utente_messaggio = $utente_mess;

if ($mostra_richiesta_via_mail == "SI" and !preg_match('/^[_\.0-9a-z-]+@([0-9a-z][0-9a-z-]+\.)+[a-z]{2,4}$/i',$indirizzo_email) and !$utente_messaggio) {
$continua = "NO";
if ($silenzio == "NO") echo mex("Indirizzo email non valido",$pag).".<br>";
} # fine if ($mostra_richiesta_via_mail == "SI" and ...

if ($utente_messaggio and $utente_messaggio != "tutti") {
if (@get_magic_quotes_gpc()) $utente_messaggio = stripslashes($utente_messaggio);
$utente_esistente = esegui_query("select idutenti from $tableutenti where nome_utente = '".aggslashdb($utente_messaggio)."'");
if (numlin_query($utente_esistente) != 1) $continua = "NO";
} # fine if ($utente_messaggio and $utente_messaggio != "tutti")

if ((string) $orig_prenota != "") {
$origini_prenota = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'origini_prenota' and idutente = '1'");
$origini_prenota = risul_query($origini_prenota,0,'valpersonalizza');
if ($origini_prenota) {
if (get_magic_quotes_gpc()) $orig_prenota = stripslashes($orig_prenota);
$origini_prenota = explode(",",$origini_prenota);
$trovato = "NO";
for ($num1 = 0 ; $num1 < count($origini_prenota) ; $num1++) if ($origini_prenota[$num1] == $orig_prenota) $trovato = "SI";
if ($trovato == "NO") $orig_prenota = "";
} # fine if ($origini_prenota)
else $orig_prenota = "";
} # fine if ((string) $orig_prenota != "")

if ($chiedi_cognome != "SI" and $chiedi_cognome != "opzionale" and $chiedi_cognome != "NO") $chiedi_cognome = "NO";
if ($chiedi_nome != "SI" and $chiedi_nome != "opzionale" and $chiedi_nome != "NO") $chiedi_nome = "opzionale";
if ($chiedi_email != "SI" and $chiedi_email != "opzionale" and $chiedi_email != "NO") $chiedi_email = "SI";
if ($chiedi_sesso != "SI" and $chiedi_sesso != "opzionale" and $chiedi_sesso != "NO") $chiedi_sesso = "NO";
if ($chiedi_datanascita != "SI" and $chiedi_datanascita != "opzionale" and $chiedi_datanascita != "NO") $chiedi_datanascita = "NO";
if ($chiedi_documento != "SI" and $chiedi_documento != "opzionale" and $chiedi_documento != "NO") $chiedi_documento = "NO";
if ($chiedi_nazione != "SI" and $chiedi_nazione != "opzionale" and $chiedi_nazione != "NO") $chiedi_nazione = "NO";
if ($chiedi_citta != "SI" and $chiedi_citta != "opzionale" and $chiedi_citta != "NO") $chiedi_citta = "NO";
if ($chiedi_regione != "SI" and $chiedi_regione != "opzionale" and $chiedi_regione != "NO") $chiedi_regione = "NO";
if ($chiedi_via != "SI" and $chiedi_via != "opzionale" and $chiedi_via != "NO") $chiedi_via = "NO";
if ($chiedi_numcivico != "SI" and $chiedi_numcivico != "opzionale" and $chiedi_numcivico != "NO") $chiedi_numcivico = "NO";
if ($chiedi_cap != "SI" and $chiedi_cap != "opzionale" and $chiedi_cap != "NO") $chiedi_cap = "NO";
if ($chiedi_telefono != "SI" and $chiedi_telefono != "opzionale" and $chiedi_telefono != "NO") $chiedi_telefono = "NO";
if ($chiedi_telefono2 != "SI" and $chiedi_telefono2 != "opzionale" and $chiedi_telefono2 != "NO") $chiedi_telefono2 = "NO";
if ($chiedi_telefono3 != "SI" and $chiedi_telefono3 != "opzionale" and $chiedi_telefono3 != "NO") $chiedi_telefono3 = "NO";
if ($chiedi_fax != "SI" and $chiedi_fax != "opzionale" and $chiedi_fax != "NO") $chiedi_fax = "NO";
if ($chiedi_codfiscale != "SI" and $chiedi_codfiscale != "opzionale" and $chiedi_codfiscale != "NO") $chiedi_codfiscale = "opzionale";
if ($chiedi_partitaiva != "SI" and $chiedi_partitaiva != "opzionale" and $chiedi_partitaiva != "NO") $chiedi_partitaiva = "opzionale";
if ($chiedi_commento != "SI" and $chiedi_commento != "opzionale" and $chiedi_commento != "NO") $chiedi_commento = "opzionale";
if ($chiedi_oracheckin != "SI" and $chiedi_oracheckin != "opzionale" and $chiedi_oracheckin != "NO") $chiedi_oracheckin = "NO";
if ($chiedi_metodopagamento != "SI" and $chiedi_metodopagamento != "opzionale" and $chiedi_metodopagamento != "NO") $chiedi_metodopagamento = "NO";

if (!$num_metodi_pagamento) $num_metodi_pagamento = 0;
if (!$num_campi_pers) $num_campi_pers = 0;
if (!$num_codici_promo) $num_codici_promo = 0;
if (controlla_num_pos($num_metodi_pagamento) == "NO") $continua = "NO";
if (controlla_num_pos($num_campi_pers) == "NO") $continua = "NO";
if (controlla_num_pos($num_codici_promo) == "NO") $continua = "NO";

$campi_form_doc_condizioni = "";
$chiedi_campi_form_doc_condizioni = "";
if (!$num_campi_doc_cond) $num_campi_doc_cond = 0;
if (controlla_num_pos($num_campi_doc_cond) == "NO") $continua = "NO";
else {
$num_campo_doc_cond = 0;
$doc_usati = "";
for ($num1 = 1 ; $num1 <= $num_campi_doc_cond ; $num1++) {
$num_doc_cond = "num_doc_cond".$num1;
$chiedi_num_doc_cond = "chiedi_num_doc_cond".$num1;
global $$num_doc_cond,$$chiedi_num_doc_cond;
if (strcmp($$num_doc_cond,"") and !$doc_usati[$$num_doc_cond]) {
if (controlla_num_pos($$num_doc_cond) == "NO") $continua = "NO";
else {
$contr_txt = esegui_query("select numero from $tablecontratti where (tipo = 'contrtxt' or tipo = 'contrhtm') and numero = '".$$num_doc_cond."' ");
if (!numlin_query($contr_txt)) {
if ($silenzio == "NO") $continua = "NO";
} # fine if (!numlin_query($contr_txt))
else {
$salva_contr = esegui_query("select * from $tablecontratti where numero = '".$$num_doc_cond."' and tipo = 'dir' ");
if (numlin_query($salva_contr)) {
if ($silenzio == "NO") $continua = "NO";
} # fine if (numlin_query($salva_contr))
else {
$$chiedi_num_doc_cond = formatta_input_var_x_file($$chiedi_num_doc_cond);
$doc_usati[$$num_doc_cond] = 1;
$num_campo_doc_cond++;
$campi_form_doc_condizioni .= "\"".$num_campo_doc_cond."\" => \"".$$num_doc_cond."\",";
$chiedi_campi_form_doc_condizioni .= "\"".$num_campo_doc_cond."\" => \"".mex($$chiedi_num_doc_cond,$pag)."\",";
} # fine else if (numlin_query($salva_contr))
} # fine else if (!numlin_query($contr_txt))
} # fine else if (controlla_num_pos($num_doc_email_conferma) == "NO")
} # fine if (strcmp($$num_doc_cond,"") and !$doc_usati[$$num_doc_cond])
} # fine for $num1
if ($campi_form_doc_condizioni) $campi_form_doc_condizioni = substr($campi_form_doc_condizioni,0,-1);
if ($chiedi_campi_form_doc_condizioni) $chiedi_campi_form_doc_condizioni = substr($chiedi_campi_form_doc_condizioni,0,-1);
} # fine else if (controlla_num_pos($num_campi_doc_cond) == "NO")

} # fine if ($continua != "NO")


if ($continua != "NO") {

$tariffe_mostra = "";
$nomi_tariffe_imposte = "";
unset($regola2_tariffa);
$tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
$regole2 = esegui_query("select * from $tableregole_modello where tariffa_per_app != ''");
$num_regole2 = numlin_query($regole2);
for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) $regola2_tariffa[risul_query($regole2,$num1,'tariffa_per_app')] = 1;
$tariffa_senza_regola2 = 0;
for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
$tariffa = "tariffa".$numtariffa;
global $$tariffa;
if ($$tariffa == "SI") {
$tariffe_mostra .= " $numtariffa => \"".mex("SI",$pag)."\",";
if (!$regola2_tariffa[$tariffa]) $tariffa_senza_regola2 = 1;
} # fine if ($$tariffa == "SI")
$nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
global $$nome_tariffa_imposto;
$$nome_tariffa_imposto = formatta_input_var_x_file($$nome_tariffa_imposto);
if ($$nome_tariffa_imposto) $nomi_tariffe_imposte .= "$numtariffa => \"".$$nome_tariffa_imposto."\",";
} # fine for $numtariffa
if ($tariffe_mostra) $tariffe_mostra = substr($tariffe_mostra,0,-1);
if ($nomi_tariffe_imposte) $nomi_tariffe_imposte = substr($nomi_tariffe_imposte,0,-1);
if ($tariffa_senza_regola2 and $silenzio == "NO") echo "<b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("ci sono tariffe senza regola di assegnazione n. 2",$pag)." (".strtolower(mex("Mobile in tutti gli appartamenti",'unit.php')).").<br><br>";

unset($nomi_costi_imposti);
unset($costi_attivati);
unset($nomi_categorie_imposte);
unset($nomi_cat_presenti);
for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
global ${"attiva_costo".$dati_ca[$numca]['id']};
if (${"attiva_costo".$dati_ca[$numca]['id']} == "SI") $costi_attivati .= " ".$dati_ca[$numca]['id']." => \"".mex("SI",$pag)."\",";
$nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
global $$nome_costo_imposto;
$$nome_costo_imposto = formatta_input_var_x_file($$nome_costo_imposto);
if (strcmp($$nome_costo_imposto,"")) $nomi_costi_imposti .= $dati_ca[$numca]['id']." => \"".$$nome_costo_imposto."\",";
if ($dati_ca[$numca]['combina'] == "s" and !$nomi_cat_presenti[$dati_ca[$numca]['categoria']]) {
$nome_cat_imp = "nome_cat_imp".$dati_ca[$numca]['id'];
global $$nome_cat_imp;
$$nome_cat_imp = formatta_input_var_x_file($$nome_cat_imp);
if ($$nome_cat_imp) {
$nomi_cat_presenti[$dati_ca[$numca]['categoria']] = 1;
$categoria = formatta_input_var_x_file($dati_ca[$numca]['categoria']);
$nomi_categorie_imposte .= "\"$categoria\" => \"".$$nome_cat_imp."\",";
} # fine if ($$nome_cat_imp)
} # fine if ($dati_ca[$numca]['combina'] == "s")
} # fine for $numca
if ($nomi_costi_imposti) $nomi_costi_imposti = substr($nomi_costi_imposti,0,-1);
if ($costi_attivati) $costi_attivati = substr($costi_attivati,0,-1);
if ($nomi_categorie_imposte) $nomi_categorie_imposte = substr($nomi_categorie_imposte,0,-1);

$campi_codici_promo = "";
$costi_campi_codici_promo = "";
$num_codice_promo = 0;
$costi_senza_associa = "";
for ($num1 = 1 ; $num1 <= $num_codici_promo ; $num1++) {
$codice_promo = "codice_promo".$num1;
$tipo_codice_promo = "tipo_codice_promo".$num1;
$costo_codice_promo = "costo_codice_promo".$num1;
global $$codice_promo,$$tipo_codice_promo,$$costo_codice_promo;
if (get_magic_quotes_gpc()) $$codice_promo = stripslashes($$codice_promo);
$$codice_promo = formatta_input_var_x_file($$codice_promo);
$$costo_codice_promo = formatta_input_var_x_file($$costo_codice_promo);
if ($$codice_promo and ($$tipo_codice_promo == "+" or $$tipo_codice_promo == "-") and strcmp($dati_ca['id'][$$costo_codice_promo],"") and $$costo_codice_promo != $costo_aggiungi_letti) {
$num_codice_promo++;
$campi_codici_promo .= "\"".$num_codice_promo."\" => \"".$$codice_promo."\",";
$costi_campi_codici_promo .= "\"".$num_codice_promo."\" => \"".$$tipo_codice_promo.$$costo_codice_promo."\",";
if ($$tipo_codice_promo == "+" and $silenzio == "NO") {
$costo_associato = 0;
for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) if ($dati_ca[$dati_ca['id'][$$costo_codice_promo]]['tariffa'.$numtariffa]) $costo_associato = 1;
if (!$costo_associato) $costi_senza_associa .= ", \"<em>".$dati_ca[$dati_ca['id'][$$costo_codice_promo]]['nome']."</em>\"";
} # fine if ($$tipo_codice_promo == "+" and $silenzio == "NO")
} # fine if ($$codice_promo and ($$tipo_codice_promo == "+" or...
} # fine for $num1
#if ($costi_senza_associa) echo "<b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("alcuni costi aggiuntivi con codice promozionale",$pag)." (".substr($costi_senza_associa,2).") ".mex("non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili",$pag).".<br><br>";
if ($campi_codici_promo) $campi_codici_promo = substr($campi_codici_promo,0,-1);
if ($costi_campi_codici_promo) $costi_campi_codici_promo = substr($costi_campi_codici_promo,0,-1);

$motivazioni_regola1 = "";
for ($num1 = 0 ; $num1 < $num_motivazioni ; $num1 = $num1 + 1) {
$var_motivazione = "var_mot_".$num1;
global $$var_motivazione;
$motivazione = $$var_motivazione;
if ($motivazione) {
$motivazione = formatta_input_var_x_file($motivazione);
$motivazioni_regola1 .= "\"$motivazione\" => \"".mex("SI",$pag)."\",";
} # fine if ($motivazione)
} # fine for $num1
if ($motivazioni_regola1) $motivazioni_regola1 = substr($motivazioni_regola1,0,-1);

if ($utente_messaggio == "tutti") $utente_messaggio = mex("tutti",$pag);

$metodi_pagamento_da_chiedere = "";
$nomi_metodi_pagamento_imposti = "";
$metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '1'");
$metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
$metodi_pagamento = explode(",",$metodi_pagamento);
for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $esiste_met_paga[$metodi_pagamento[$num1]] = "SI";
for ($num1 = 0 ; $num1 < $num_metodi_pagamento ; $num1++) {
$var_met_paga = "var_met_paga_".$num1;
$nome_met_paga_imposto = "nome_met_paga_imposto_".$num1;
global $$var_met_paga,$$nome_met_paga_imposto;
$met_paga_compara = $$var_met_paga;
if (@get_magic_quotes_gpc()) $met_paga_compara = stripslashes($met_paga_compara);
else $met_paga_compara = $$var_met_paga;
if ($$var_met_paga and $esiste_met_paga[$met_paga_compara]) {
$$var_met_paga = formatta_input_var_x_file($$var_met_paga);
$$nome_met_paga_imposto = formatta_input_var_x_file($$nome_met_paga_imposto);
$metodi_pagamento_da_chiedere .= "\"".$$var_met_paga."\" => \"".mex("SI",$pag)."\",";
if ($$nome_met_paga_imposto) $nomi_metodi_pagamento_imposti .= "\"".$$var_met_paga."\" => \"".$$nome_met_paga_imposto."\",";
} # fine ($$var_met_paga and $esiste_met_paga[$$var_met_paga])
} # fine for $num1
if ($metodi_pagamento_da_chiedere) $metodi_pagamento_da_chiedere = substr($metodi_pagamento_da_chiedere,0,-1);
if ($nomi_metodi_pagamento_imposti) $nomi_metodi_pagamento_imposti = substr($nomi_metodi_pagamento_imposti,0,-1);

$campi_form_personalizzati = "";
$chiedi_campi_form_personalizzati = "";
$ins_campi_form_personalizzati = "";
$num_campo_pers = 0;
for ($num1 = 1 ; $num1 <= $num_campi_pers ; $num1++) {
$campo_pers = "campo_pers".$num1;
$chiedi_campo_pers = "chiedi_campo_pers".$num1;
$ins_campo_pers = "ins_campo_pers".$num1;
global $$campo_pers,$$chiedi_campo_pers,$$ins_campo_pers;
if (get_magic_quotes_gpc()) $$campo_pers = stripslashes($$campo_pers);
$$campo_pers = formatta_input_var_x_file($$campo_pers);
$$ins_campo_pers = formatta_input_var_x_file($$ins_campo_pers);
if ($$campo_pers and ($$chiedi_campo_pers == "SI" or $$chiedi_campo_pers == "opzionale")) {
$num_campo_pers++;
$campi_form_personalizzati .= "\"".$num_campo_pers."\" => \"".$$campo_pers."\",";
$chiedi_campi_form_personalizzati .= "\"".$num_campo_pers."\" => \"".mex($$chiedi_campo_pers,$pag)."\",";
$ins_campi_form_personalizzati .= "\"".$num_campo_pers."\" => \"".$$ins_campo_pers."\",";
} # fine if ($$campo_pers and...
} # fine for $num1
if ($campi_form_personalizzati) $campi_form_personalizzati = substr($campi_form_personalizzati,0,-1);
if ($chiedi_campi_form_personalizzati) $chiedi_campi_form_personalizzati = substr($chiedi_campi_form_personalizzati,0,-1);
if ($ins_campi_form_personalizzati) $ins_campi_form_personalizzati = substr($ins_campi_form_personalizzati,0,-1);

if (!$mostra_quadro_disp) {
$mostra_quadro_disponibilita = "NO";
$raggruppa_quadro_disponibilita_con_regola_2 = "NO";
$raggruppa_quadro_disponibilita_con_persone = "NO";
} # fine if (!$mostra_quadro_disp)
else {
$mostra_quadro_disponibilita = "SI";
if ($mostra_quadro_disp == "reg2") $raggruppa_quadro_disponibilita_con_regola_2 = "SI";
else $raggruppa_quadro_disponibilita_con_regola_2 = "NO";
if ($mostra_quadro_disp == "pers") $raggruppa_quadro_disponibilita_con_persone = "SI";
else $raggruppa_quadro_disponibilita_con_persone = "NO";
} # fine else if (!$mostra_quadro_disp)
if ($mostra_numero_liberi_quadro_disponibilita != "SI") $mostra_numero_liberi_quadro_disponibilita = "NO";
if ($allinea_disponibilita_con_arrivo != "SI") $allinea_disponibilita_con_arrivo = "NO";

if (substr($spostamento_orizzontale_calendario,0,1) == "+") $spostamento_orizzontale_calendario = substr($spostamento_orizzontale_calendario,1);
if (!strcmp($spostamento_orizzontale_calendario,"") or controlla_num($spostamento_orizzontale_calendario) == "NO") $spostamento_orizzontale_calendario = 2;

if (defined("C_MASCHERA_EMAIL") and C_MASCHERA_EMAIL != "") $maschera_envelope = C_MASCHERA_EMAIL;
if (C_RESTRIZIONI_DEMO_ADMIN == "SI") {
$indirizzo_email = C_EMAIL_DEMO_ADMIN;
$manda_copia_richiesta_email = "NO";
} # fine if (C_RESTRIZIONI_DEMO_ADMIN == "SI")

if ($file_css_frame == "http://") $file_css_frame = "";
if ($apri_nuova_finestra_da_frame != "SI") $apri_nuova_finestra_da_frame = "NO";
if (!$larghezza_finestra_da_frame or controlla_num_pos($larghezza_finestra_da_frame) == "NO") $larghezza_finestra_da_frame = "700";
if (!$altezza_finestra_da_frame or controlla_num_pos($altezza_finestra_da_frame) == "NO") $altezza_finestra_da_frame = "620";

$num_colori = 0;
$extra_head_frame = "";
if (strcmp($tema_modello,"")) {
include("./includes/templates/temi_mod_disp.php");
$num_temi = count($template_theme_name);
for ($num1 = 1 ; $num1 <= $num_temi ; $num1++) {
if ($tema_modello == $template_theme_name[$num1]) {
$tema_trovato = 1;
$tema_sel = $num1;
} # fine if ($tema_modello == $template_theme_name[$num1])
} # fine for $num1
if ($tema_trovato) {
$prima_parte_html = $template_theme_html_pre[$tema_sel];
$ultima_parte_html = $template_theme_html_post[$tema_sel];
$extra_head_frame = $framed_mode_extra_head[$tema_sel];
$valori_tema = $template_theme_values[$tema_sel];
$num_valori = count($valori_tema);
for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
global ${"valore_tema_".$num1};
${"valore_tema_".$num1} = formatta_input_var_x_file(${"valore_tema_".$num1});
$valore_sost = ${"valore_tema_".$num1};
if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
elseif (strcmp($valori_tema[$num1]['replace'],"")) $valore_sost = str_replace("[theme_value_$num1]",$valore_sost,$valori_tema[$num1]['replace']);
$prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_html);
$ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
$extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
} # fine for $num1
$colori_tema = $template_theme_colors[$tema_sel];
$num_colori = count($colori_tema);
for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) {
global ${"colore_tema_".$num1};
if (!preg_match("/^#[0-9a-f]{3,3}$/i",${"colore_tema_".$num1}) and !preg_match("/^#[0-9a-f]{6,6}$/i",${"colore_tema_".$num1})) ${"colore_tema_".$num1} = $colori_tema[$num1]['default'];
$prima_parte_html = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$prima_parte_html);
$ultima_parte_html = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$ultima_parte_html);
$extra_head_frame = str_replace("[theme_color_$num1]",${"colore_tema_".$num1},$extra_head_frame);
} # fine for $num1
} # fine if ($tema_trovato)
else $tema_modello = "";
} # fine if (strcmp($tema_modello,""))

if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) {
$HOTELD_DB_TYPE = "";
$HOTELD_DB_NAME = "";
$HOTELD_DB_HOST = "";
$HOTELD_DB_PORT = "";
$HOTELD_DB_USER = "";
$HOTELD_DB_PASS = "";
$HOTELD_TAB_PRE = "";
include(C_EXT_DB_DATA_PATH);
if ($HOTELD_DB_TYPE) $M_PHPR_DB_TYPE = "";
if ($HOTELD_DB_NAME) $M_PHPR_DB_NAME = "";
if ($HOTELD_DB_HOST) $M_PHPR_DB_HOST = "";
if (strcmp($HOTELD_DB_PORT,"")) $M_PHPR_DB_PORT = "";
if ($HOTELD_DB_USER) $M_PHPR_DB_USER = "";
if (strcmp($HOTELD_DB_PASS,"")) $M_PHPR_DB_PASS = "";
if ($HOTELD_TAB_PRE) $M_PHPR_TAB_PRE = "";
} # fine if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH)

$M_PHPR_DB_TYPE = formatta_input_var_x_file($M_PHPR_DB_TYPE);
$M_PHPR_DB_NAME = formatta_input_var_x_file($M_PHPR_DB_NAME);
$M_PHPR_DB_HOST = formatta_input_var_x_file($M_PHPR_DB_HOST);
$M_PHPR_DB_PORT = formatta_input_var_x_file($M_PHPR_DB_PORT);
$M_PHPR_DB_USER = formatta_input_var_x_file($M_PHPR_DB_USER);
$M_PHPR_DB_PASS = formatta_input_var_x_file($M_PHPR_DB_PASS);
$M_PHPR_LOAD_EXT = formatta_input_var_x_file($M_PHPR_LOAD_EXT);
$M_PHPR_TAB_PRE = formatta_input_var_x_file($M_PHPR_TAB_PRE);
$m_stile_soldi = formatta_input_var_x_file($m_stile_soldi);
$m_stile_data = formatta_input_var_x_file($m_stile_data);
$anteponi_nome_valuta = formatta_input_var_x_file($anteponi_nome_valuta);
$parola_appartamenti = formatta_input_var_x_file($parola_appartamenti);
$parola_appartamento = formatta_input_var_x_file($parola_appartamento);
$chiedi_num_persone = formatta_input_var_x_file($chiedi_num_persone);
$aggiungi_costi_fissi = formatta_input_var_x_file($aggiungi_costi_fissi);
$mostra_costi_aggiuntivi = formatta_input_var_x_file($mostra_costi_aggiuntivi);
$assegna_con_regola2 = formatta_input_var_x_file($assegna_con_regola2);
$mostra_frase_alternativa_regola1 = formatta_input_var_x_file($mostra_frase_alternativa_regola1);
$mostra_caparra = formatta_input_var_x_file($mostra_caparra);
$mostra_richiesta_via_mail = formatta_input_var_x_file($mostra_richiesta_via_mail);
$indirizzo_email = formatta_input_var_x_file($indirizzo_email);
$manda_copia_richiesta_email = formatta_input_var_x_file($manda_copia_richiesta_email);
$maschera_envelope = formatta_input_var_x_file($maschera_envelope);
$mostra_giorni_pieni = formatta_input_var_x_file($mostra_giorni_pieni);
$orig_prenota = formatta_input_var_x_file($orig_prenota);
$mostra_bottone_paypal = formatta_input_var_x_file($mostra_bottone_paypal);
$nome_modello_paypal = formatta_input_var_x_file($nome_modello_paypal);
$colore_sfondo_quadro_disponibilita = formatta_input_var_x_file($colore_sfondo_quadro_disponibilita);
$colore_inizio_settimana_quadro_disponibilita = formatta_input_var_x_file($colore_inizio_settimana_quadro_disponibilita);
$colore_libero_quadro_disponibilita = formatta_input_var_x_file($colore_libero_quadro_disponibilita);
$colore_occupato_quadro_disponibilita = formatta_input_var_x_file($colore_occupato_quadro_disponibilita);
$apertura_font_quadro_disponibilita = formatta_input_var_x_file($apertura_font_quadro_disponibilita);
$chiusura_font_quadro_disponibilita = formatta_input_var_x_file($chiusura_font_quadro_disponibilita);
$apertura_tag_font = formatta_input_var_x_file($apertura_tag_font);
$chiusura_tag_font = formatta_input_var_x_file($chiusura_tag_font);
$apertura_tag_font_rosse = formatta_input_var_x_file($apertura_tag_font_rosse);
$chiusura_tag_font_rosse = formatta_input_var_x_file($chiusura_tag_font_rosse);
$stile_tabella_prenotazione = formatta_input_var_x_file($stile_tabella_prenotazione);
$mostra_calendario_scelta_date = formatta_input_var_x_file($mostra_calendario_scelta_date);
$stile_riquadro_calendario = formatta_input_var_x_file($stile_riquadro_calendario);
$stile_tabella_calendario = formatta_input_var_x_file($stile_tabella_calendario);
$stile_bottoni_calendario = formatta_input_var_x_file($stile_bottoni_calendario);
$stile_bottone_apertura_calendario = formatta_input_var_x_file($stile_bottone_apertura_calendario);
$colore_data_attiva_calendario = formatta_input_var_x_file($colore_data_attiva_calendario);
$colore_data_selezionata_calendario = formatta_input_var_x_file($colore_data_selezionata_calendario);
$m_valuta_sing = formatta_input_var_x_file($m_valuta_sing);
$m_valuta_plur = formatta_input_var_x_file($m_valuta_plur);
$frase_alternativa_regola1 = formatta_input_var_x_file($frase_alternativa_regola1);
$file_css_frame = formatta_input_var_x_file($file_css_frame);
$extra_head_frame = formatta_input_var_x_file($extra_head_frame);
if (get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
$prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
$prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
$prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
$prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
$prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
if (get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
$ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
$ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
$ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
$ultima_parte_html = str_replace("%>","ERROR",$ultima_parte_html);
$ultima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$ultima_parte_html);
# FRASI
if ($cambia_frasi == "SI" or $modello_esistente == "SI") {
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
global ${$fr_frase[$num_fr]};
${$fr_frase[$num_fr]} = formatta_input_var_x_file(${$fr_frase[$num_fr]});
} # fine for $num_fr
} # fine if ($cambia_frasi == "SI" or $modello_esistente == "SI")
else {
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) ${$fr_frase[$num_fr]} = mex2($frase[$num_fr],$pag,$lingua_modello);
} # fine else if ($cambia_frasi == "SI" or $modello_esistente == "SI")

$cost_percorso_a_dati = "";
if (function_exists("realpath")) {
if (realpath(C_DATI_PATH."/")) $cost_percorso_a_dati = realpath(C_DATI_PATH."/")."/";
} # fine if (function_exists("realpath"))
if ((string) $cost_percorso_a_dati == "") {
if (substr(C_DATI_PATH,0,1) == "/") $cost_percorso_a_dati = C_DATI_PATH;
else {
$dati_path = C_DATI_PATH;
if (substr($dati_path,0,2) == "./") $dati_path = substr($dati_path,1);
else $dati_path = "/".$dati_path;
if ($_SERVER["SCRIPT_FILENAME"]) $cost_percorso_a_dati = dirname($_SERVER["SCRIPT_FILENAME"]).$dati_path;
else {
if ($HTTP_SERVER_VARS["SCRIPT_FILENAME"]) $cost_percorso_a_dati = dirname($HTTP_SERVER_VARS["SCRIPT_FILENAME"]).$dati_path;
else {
if ($SCRIPT_FILENAME) $cost_percorso_a_dati = dirname($SCRIPT_FILENAME).$dati_path;
else $cost_percorso_a_dati = "./";
} # fine else if ($HTTP_SERVER_VARS["SCRIPT_FILENAME"])
} # fine else if ($_SERVER["SCRIPT_FILENAME"])
} # fine else if (substr(C_DATI_PATH,0,1) == "/")
} # fine if ((string) $cost_percorso_a_dati == "")

$nome_file = mex2("mdl_disponibilita",$pag,$lingua_modello).".php";
$file = @fopen("$percorso_cartella_modello/$nome_file","w+");
if ($file) {
flock($file,2);
fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed']) { ?>$prima_parte_html




<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->


<?php
} # fine if (!\$framed and !\$_GET['framed'] and !\$_POST['framed'])


# ".mex("INIZIO VARIABILI MODIFICABILI",$pag)." (".mex("modificare il valore sulla destra",$pag).")

# ".mex("Inserire in questa variabile il nome della pagina se \$PHP_SELF non è definita",$pag)."
\$".mex("var_nome_pagina",$pag)." = \"\";

\$".mex("var_anno",$pag)." = $anno_modello;
\$".mex("var_tipo_db",$pag)." = \"$M_PHPR_DB_TYPE\";
\$".mex("var_nome_db",$pag)." = \"$M_PHPR_DB_NAME\";
\$".mex("var_computer_db",$pag)." = \"$M_PHPR_DB_HOST\";
\$".mex("var_porta_db",$pag)." = \"$M_PHPR_DB_PORT\";
\$".mex("var_utente_db",$pag)." = \"$M_PHPR_DB_USER\";
\$".mex("var_password_db",$pag)." = \"$M_PHPR_DB_PASS\";
\$".mex("var_carica_estensione_db",$pag)." = \"".mex("$M_PHPR_LOAD_EXT",$pag)."\";
\$".mex("var_prefisso_tabelle_db",$pag)." = \"$M_PHPR_TAB_PRE\";
\$".mex("var_lingua_modello",$pag)." = \"$lingua_modello\";
\$".mex("var_stile_soldi",$pag)." = \"".mex("$m_stile_soldi",$pag)."\";
\$".mex("var_stile_data",$pag)." = \"".mex("$m_stile_data",$pag)."\";
\$".mex("var_anteponi_nome_valuta",$pag)." = \"".mex("$anteponi_nome_valuta",$pag)."\";
\$".mex("var_utente_liste",$pag)." = \"".mex("$utente_liste",$pag)."\";
\$".mex("var_estendi_ultima_data",$pag)." = \"".mex("$estendi_ultima_data",$pag)."\";
\$".mex("var_periodi_no_richieste",$pag)." = \"$sett_no_prenota\";
\$".mex("var_tariffe_mostra",$pag)." = array($tariffe_mostra);
\$".mex("var_nomi_tariffe_imposte",$pag)." = array($nomi_tariffe_imposte);
\$".mex("var_chiedi_numero_appartamenti_per_tipologia",$pag)." = \"".mex("$chiedi_num_app_tipologia",$pag)."\";
\$".mex("var_massimo_numero_appartamenti_per_tipologia",$pag)." = \"$max_num_app_tipologia\";
\$".mex("var_aggiungi_altre_tipologie",$pag)." = \"".mex("$aggiungi_tipologie",$pag)."\";
\$".mex("var_massimo_numero_altre_tipologie",$pag)." = \"$max_num_tipologie\";
\$".mex("var_cerca_appartamenti_vicini",$pag)." = \"".mex("$cerca_app_vicini",$pag)."\";
\$".mex("var_chiedi_numero_persone",$pag)." = \"".mex("$chiedi_num_persone",$pag)."\";
\$".mex("var_massimo_numero_persone",$pag)." = \"$max_num_persone\";
\$".mex("var_costo_aggiungi_letti",$pag)." = \"$costo_aggiungi_letti\";
\$".mex("var_massimo_numero_letti_aggiuntivi",$pag)." = \"$max_num_aggiungi_letti\";
\$".mex("var_aggiungi_costi_fissi",$pag)." = \"".mex("$aggiungi_costi_fissi",$pag)."\";
\$".mex("var_chiedi_costi_aggiuntivi_di_pag_inserzione",$pag)." = \"".mex("$mostra_costi_aggiuntivi",$pag)."\";
\$".mex("var_numero_colonne_costi_aggiuntivi",$pag)." = \"$num_colonne_costi_agg\";
\$".mex("var_costi_aggiuntivi_mostra",$pag)." = array($costi_attivati);
\$".mex("var_nomi_costi_agg_imposti",$pag)." = array($nomi_costi_imposti);
\$".mex("var_categorie_costi_agg_imposte",$pag)." = array($nomi_categorie_imposte);
\$".mex("var_campi_codici_promo",$pag)." = array($campi_codici_promo);
\$".mex("var_costi_campi_codici_promo",$pag)." = array($costi_campi_codici_promo);
\$".mex("var_assegna_con_regola2",$pag)." = \"".mex("$assegna_con_regola2",$pag)."\";
\$".mex("var_considera_motivazioni_regola1",$pag)." = array($motivazioni_regola1);
\$".mex("var_mostra_frase_alternativa_regola1",$pag)." = \"".mex("$mostra_frase_alternativa_regola1",$pag)."\";
\$".mex("var_mostra_caparra",$pag)." = \"".mex("$mostra_caparra",$pag)."\";
\$".mex("var_mostra_richiesta_via_mail",$pag)." = \"".mex("$mostra_richiesta_via_mail",$pag)."\";
\$".mex("var_indirizzo_email",$pag)." = \"$indirizzo_email\";
\$".mex("var_manda_copia_richiesta_email",$pag)." = \"".mex("$manda_copia_richiesta_email",$pag)."\";
\$".mex("var_maschera_email",$pag)." = \"".mex("$maschera_envelope",$pag)."\";
\$".mex("var_mostra_giorni_pieni",$pag)." = \"".mex("$mostra_giorni_pieni",$pag)."\";
\$".mex("var_mostra_bottone_paypal",$pag)." = \"".mex("$mostra_bottone_paypal",$pag)."\";
\$".mex("var_nome_modello_paypal",$pag)." = \"".$nome_modello_paypal."\";
\$".mex("var_utente_messaggio",$pag)." = \"$utente_messaggio\";
\$".mex("var_origine_prenotazione",$pag)." = \"".$orig_prenota."\";

\$".mex("var_chiedi_cognome",$pag)." = \"".mex("$chiedi_cognome",$pag)."\";
\$".mex("var_chiedi_nome",$pag)." = \"".mex("$chiedi_nome",$pag)."\";
\$".mex("var_chiedi_email",$pag)." = \"".mex("$chiedi_email",$pag)."\";
\$".mex("var_chiedi_sesso",$pag)." = \"".mex("$chiedi_sesso",$pag)."\";
\$".mex("var_chiedi_datanascita",$pag)." = \"".mex("$chiedi_datanascita",$pag)."\";
\$".mex("var_chiedi_documento",$pag)." = \"".mex("$chiedi_documento",$pag)."\";
\$".mex("var_chiedi_nazione",$pag)." = \"".mex("$chiedi_nazione",$pag)."\";
\$".mex("var_chiedi_citta",$pag)." = \"".mex("$chiedi_citta",$pag)."\";
\$".mex("var_chiedi_regione",$pag)." = \"".mex("$chiedi_regione",$pag)."\";
\$".mex("var_chiedi_via",$pag)." = \"".mex("$chiedi_via",$pag)."\";
\$".mex("var_chiedi_numcivico",$pag)." = \"".mex("$chiedi_numcivico",$pag)."\";
\$".mex("var_chiedi_cap",$pag)." = \"".mex("$chiedi_cap",$pag)."\";
\$".mex("var_chiedi_telefono",$pag)." = \"".mex("$chiedi_telefono",$pag)."\";
\$".mex("var_chiedi_telefono2",$pag)." = \"".mex("$chiedi_telefono2",$pag)."\";
\$".mex("var_chiedi_telefono3",$pag)." = \"".mex("$chiedi_telefono3",$pag)."\";
\$".mex("var_chiedi_fax",$pag)." = \"".mex("$chiedi_fax",$pag)."\";
\$".mex("var_chiedi_codfiscale",$pag)." = \"".mex("$chiedi_codfiscale",$pag)."\";
\$".mex("var_chiedi_partitaiva",$pag)." = \"".mex("$chiedi_partitaiva",$pag)."\";
\$".mex("var_chiedi_commento",$pag)." = \"".mex("$chiedi_commento",$pag)."\";
\$".mex("var_chiedi_oracheckin",$pag)." = \"".mex("$chiedi_oracheckin",$pag)."\";
\$".mex("var_chiedi_metodopagamento",$pag)." = \"".mex("$chiedi_metodopagamento",$pag)."\";
\$".mex("var_metodi_pagamento_da_chiedere",$pag)." = array($metodi_pagamento_da_chiedere);
\$".mex("var_nomi_metodi_pagamento_imposti",$pag)." = array($nomi_metodi_pagamento_imposti);
\$".mex("var_campi_form_personalizzati",$pag)." = array($campi_form_personalizzati);
\$".mex("var_chiedi_campi_form_personalizzati",$pag)." = array($chiedi_campi_form_personalizzati);
\$".mex("var_ins_campi_form_personalizzati",$pag)." = array($ins_campi_form_personalizzati);
\$".mex("var_campi_form_doc_condizioni",$pag)." = array($campi_form_doc_condizioni);
\$".mex("var_chiedi_campi_form_doc_condizioni",$pag)." = array($chiedi_campi_form_doc_condizioni);

\$".mex("var_mostra_quadro_disponibilita",$pag)." = \"".mex("$mostra_quadro_disponibilita",$pag)."\";
\$".mex("var_raggruppa_quadro_disponibilita_con_regola_2",$pag)." = \"".mex("$raggruppa_quadro_disponibilita_con_regola_2",$pag)."\";
\$".mex("var_raggruppa_quadro_disponibilita_con_persone",$pag)." = \"".mex("$raggruppa_quadro_disponibilita_con_persone",$pag)."\";
\$".mex("var_colore_sfondo_quadro_disponibilita",$pag)." = \"$colore_sfondo_quadro_disponibilita\";
\$".mex("var_colore_inizio_settimana_quadro_disponibilita",$pag)." = \"$colore_inizio_settimana_quadro_disponibilita\";
\$".mex("var_colore_libero_quadro_disponibilita",$pag)." = \"$colore_libero_quadro_disponibilita\";
\$".mex("var_colore_occupato_quadro_disponibilita",$pag)." = \"$colore_occupato_quadro_disponibilita\";
\$".mex("var_apertura_font_quadro_disponibilita",$pag)." = \"$apertura_font_quadro_disponibilita\";
\$".mex("var_chiusura_font_quadro_disponibilita",$pag)." = \"$chiusura_font_quadro_disponibilita\";
\$".mex("var_mostra_numero_liberi_quadro_disponibilita",$pag)." = \"".mex("$mostra_numero_liberi_quadro_disponibilita",$pag)."\";
\$".mex("var_allinea_disponibilita_con_arrivo",$pag)." = \"".mex("$allinea_disponibilita_con_arrivo",$pag)."\";

\$".mex("var_mostra_calendario_scelta_date",$pag)." = \"".mex("$mostra_calendario_scelta_date",$pag)."\";
\$".mex("var_stile_riquadro_calendario",$pag)." = \"$stile_riquadro_calendario\";
\$".mex("var_stile_tabella_calendario",$pag)." = \"$stile_tabella_calendario\";
\$".mex("var_stile_bottoni_calendario",$pag)." = \"$stile_bottoni_calendario\";
\$".mex("var_stile_bottone_apertura_calendario",$pag)." = \"$stile_bottone_apertura_calendario\";
\$".mex("var_spostamento_orizzontale_calendario",$pag)." = \"$spostamento_orizzontale_calendario\";
\$".mex("var_colore_data_attiva_calendario",$pag)." = \"$colore_data_attiva_calendario\";
\$".mex("var_colore_data_selezionata_calendario",$pag)." = \"$colore_data_selezionata_calendario\";

\$".mex("var_apertura_tag_font",$pag)." = \"$apertura_tag_font\";
\$".mex("var_chiusura_tag_font",$pag)." = \"$chiusura_tag_font\";
\$".mex("var_apertura_tag_font_rosse",$pag)." = \"$apertura_tag_font_rosse\";
\$".mex("var_chiusura_tag_font_rosse",$pag)." = \"$chiusura_tag_font_rosse\";
\$".mex("var_stile_tabella_prenotazione",$pag)." = \"$stile_tabella_prenotazione\";
\$".mex("var_file_css_frame",$pag)." = \"$file_css_frame\";
\$".mex("var_apri_nuova_finestra_da_frame",$pag)." = \"".mex("$apri_nuova_finestra_da_frame",$pag)."\";
\$".mex("var_larghezza_finestra_da_frame",$pag)." = \"$larghezza_finestra_da_frame\";
\$".mex("var_altezza_finestra_da_frame",$pag)." = \"$altezza_finestra_da_frame\";
\$".mex("var_tema_modello",$pag)." = \"$tema_modello\";
");
for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) fwrite($file,"\$".mex("var_colore_tema",$pag)."_$num1 = \"".${"colore_tema_".$num1}."\";
");
for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) fwrite($file,"\$".mex("var_valore_tema",$pag)."_$num1 = \"".${"valore_tema_".$num1}."\";
");
fwrite($file,"
# ".mex("FRASI",$pag)."
\$".mex("var_fr_Valuta_sing",$pag)." = \"".$m_valuta_sing."\";
\$".mex("var_fr_Valuta_plur",$pag)." = \"".$m_valuta_plur."\";
\$".mex("var_fr_appartamenti",$pag)." = \"".$parola_appartamenti."\";
\$".mex("var_fr_appartamento",$pag)." = \"".$parola_appartamento."\";
\$".mex("var_fr_alternativa_regola1",$pag)." = \"".$frase_alternativa_regola1."\";
");
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) fwrite($file,"\$".mex("var_".$fr_frase[$num_fr],$pag)." = \"".${$fr_frase[$num_fr]}."\";
");
fwrite($file,"
# ".mex("FRASI EMAIL",$pag)."
\$".mex("var_fre_Email",$pag)." = \"".mex("Email",$pag)."\";
\$".mex("var_fre_Nome",$pag)." = \"".mex("Nome",$pag)."\";
\$".mex("var_fre_Commento",$pag)." = \"".mex("Commento",$pag)."\";
\$".mex("var_fre_Periodo",$pag)." = \"".mex("Periodo",$pag)."\";
\$".mex("var_fre_dal",$pag)." = \"".mex("dal",$pag)."\";
\$".mex("var_fre_al",$pag)." = \"".mex("al",$pag)."\";
\$".mex("var_fre_Tariffa",$pag)." = \"".mex("Tariffa",$pag)."\";
\$".mex("var_fre_Costi_aggiuntivi",$pag)." = \"".mex("Costi aggiuntivi",$pag)."\";
\$".mex("var_fre_sett",$pag)." = \"".mex("$parola_settimane",$pag)."\";
\$".mex("var_fre_Numero_di_appartamenti",$pag)." = \"".mex("Numero di appartamenti",'unit.php')."\";
\$".mex("var_fre_Prezzo_totale",$pag)." = \"".mex("Prezzo totale",$pag)."\";
\$".mex("var_fre_Riferimento",$pag)." = \"".mex("Riferimento",$pag)."\";
\$".mex("var_fre_Richesta_prenotazione",$pag)." = \"".mex("Richesta prenotazione",$pag)."\";
\$".mex("var_fre_Caparra",$pag)." = \"".mex("Caparra",$pag)."\";
\$".mex("var_fre_Persone",$pag)." = \"".mex("Persone",$pag)."\";
\$".mex("var_fre_Cognome",$pag)." = \"".mex("Cognome",$pag)."\";
\$".mex("var_fre_Genere",$pag)." = \"".mex("Genere",$pag)."\";
\$".mex("var_fre_Data_di_nascita",$pag)." = \"".mex("Data di nascita",$pag)."\";
\$".mex("var_fre_Documento",$pag)." = \"".mex("Documento",$pag)."\";
\$".mex("var_fre_Nazione",$pag)." = \"".mex("Nazione",$pag)."\";
\$".mex("var_fre_Citta",$pag)." = \"".mex("Città",$pag)."\";
\$".mex("var_fre_Regione",$pag)." = \"".mex("Regione",$pag)."\";
\$".mex("var_fre_Via",$pag)." = \"".mex("Via",$pag)."\";
\$".mex("var_fre_Numero_civico",$pag)." = \"".mex("Numero civico",$pag)."\";
\$".mex("var_fre_Codice_postale",$pag)." = \"".mex("Codice postale",$pag)."\";
\$".mex("var_fre_Telefono",$pag)." = \"".mex("Telefono",$pag)."\";
\$".mex("var_fre_Secondo_telefono",$pag)." = \"".mex("Secondo telefono",$pag)."\";
\$".mex("var_fre_Terzo_telefono",$pag)." = \"".mex("Terzo telefono",$pag)."\";
\$".mex("var_fre_Fax",$pag)." = \"".mex("Fax",$pag)."\";
\$".mex("var_fre_Codice_fiscale",$pag)." = \"".mex("Codice fiscale",$pag)."\";
\$".mex("var_fre_Partita_iva",$pag)." = \"".mex("Partita iva",$pag)."\";
\$".mex("var_fre_Orario_stimato_di_arrivo",$pag)." = \"".mex("Orario stimato di arrivo",$pag)."\";
\$".mex("var_fre_Metodo_di_pagamento_della_caparra",$pag)." = \"".mex("Metodo di pagamento della caparra",$pag)."\";

# ".mex("PERIODI NEI MENU",$pag)."
\$".mex("var_periodi_menu",$pag)." = \"$date_in_menu\";

\$d_names = \"$d_names\";
\$m_names = \"$m_names\";

# ".mex("FINE VARIABILI MODIFICABILI",$pag)."



############################################################################
###        ".mex("NON MODIFICARE NIENTE A PARTIRE DA QUI",$pag)."
############################################################################


error_reporting(E_ALL ^ E_NOTICE);
\$PHPR_LOG = \"NO\";
\$pag = \$".mex("var_nome_pagina",$pag).";
if (!\$pag) {
if (@\$PHP_SELF or @\$_SERVER[\"PHP_SELF\"] or @\$HTTP_SERVER_VARS[\"PHP_SELF\"]) {
if (@\$_SERVER[\"PHP_SELF\"]) \$PHP_SELF = \$_SERVER[\"PHP_SELF\"];
else if (@\$HTTP_SERVER_VARS[\"PHP_SELF\"]) \$PHP_SELF = \$HTTP_SERVER_VARS[\"PHP_SELF\"];
\$pag = explode(\"/\",\$PHP_SELF);
\$pag = \$pag[(count(\$pag)-1)];
} # fine if (@\$PHP_SELF or @\$_SERVER[\"PHP_SELF\"] or...
else echo \"".mex("La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome",$pag).".<br>\";
} # fine if (!\$pag)

define('C_PERCORSO_A_DATI',\"$cost_percorso_a_dati\");
define('C_PAGINA_WEB','1');

\$anno = \$".mex("var_anno",$pag).";
\$PHPR_DB_TYPE = \$".mex("var_tipo_db",$pag).";
\$PHPR_DB_NAME = \$".mex("var_nome_db",$pag).";
\$PHPR_DB_HOST = \$".mex("var_computer_db",$pag).";
\$PHPR_DB_PORT = \$".mex("var_porta_db",$pag).";
\$PHPR_DB_USER = \$".mex("var_utente_db",$pag).";
\$PHPR_DB_PASS = \$".mex("var_password_db",$pag).";
if (strtoupper(\$".mex("var_carica_estensione_db",$pag).") == \"".mex("SI",$pag)."\") \$PHPR_LOAD_EXT = \"SI\";
else \$PHPR_LOAD_EXT = \"NO\";
\$PHPR_TAB_PRE = \$".mex("var_prefisso_tabelle_db",$pag).";
");
if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) fwrite($file,"\$HOTELD_DB_TYPE = \"\";
\$HOTELD_DB_NAME = \"\";
\$HOTELD_DB_HOST = \"\";
\$HOTELD_DB_PORT = \"\";
\$HOTELD_DB_USER = \"\";
\$HOTELD_DB_PASS = \"\";
\$HOTELD_TAB_PRE = \"\";
require('".C_EXT_DB_DATA_PATH."');
if (\$HOTELD_DB_TYPE) \$PHPR_DB_TYPE = \$HOTELD_DB_TYPE;
if (\$HOTELD_DB_NAME) \$PHPR_DB_NAME = \$HOTELD_DB_NAME;
if (\$HOTELD_DB_HOST) \$PHPR_DB_HOST = \$HOTELD_DB_HOST;
if (strcmp(\$HOTELD_DB_PORT,\"\")) \$PHPR_DB_PORT = \$HOTELD_DB_PORT;
if (\$HOTELD_DB_USER) \$PHPR_DB_USER = \$HOTELD_DB_USER;
if (strcmp(\$HOTELD_DB_PASS,\"\")) \$PHPR_DB_PASS = \$HOTELD_DB_PASS;
if (\$HOTELD_TAB_PRE) \$PHPR_TAB_PRE = \$HOTELD_TAB_PRE;
");
fwrite($file,"\$lingua_modello = \$".mex("var_lingua_modello",$pag).";
if (\$".mex("var_stile_soldi",$pag)." == \"".mex("europa",$pag)."\") \$stile_soldi = \"europa\";
if (\$".mex("var_stile_soldi",$pag)." == \"".mex("usa",$pag)."\") \$stile_soldi = \"usa\";
if (\$".mex("var_stile_data",$pag)." == \"".mex("europa",$pag)."\") \$stile_data = \"europa\";
if (\$".mex("var_stile_data",$pag)." == \"".mex("usa",$pag)."\") \$stile_data = \"usa\";
if (strtoupper(\$".mex("var_anteponi_nome_valuta",$pag).") == \"".mex("SI",$pag)."\") \$anteponi_nome_valuta = \"SI\";
else \$anteponi_nome_valuta = \"NO\";
\$utente_liste = \$".mex("var_utente_liste",$pag).";
if (strtoupper(\$".mex("var_estendi_ultima_data",$pag).") == \"".mex("SI",$pag)."\") \$estendi_ultima_data = \"SI\";
else \$estendi_ultima_data = \"NO\";
\$sett_no_prenota = \$".mex("var_periodi_no_richieste",$pag).";
unset(\$tariffe_mostra);
reset (\$".mex("var_tariffe_mostra",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_tariffe_mostra",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$tariffe_mostra[\$key] = \"SI\";
if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$tariffe_mostra[\$key] = \"NO\";
} # fine while
\$n_tariffe_imposte = \$".mex("var_nomi_tariffe_imposte",$pag).";
if (strtoupper(\$".mex("var_chiedi_numero_appartamenti_per_tipologia",$pag).") == \"".mex("SI",$pag)."\") \$chiedi_num_app_tipologia = \"SI\";
else \$chiedi_num_app_tipologia = \"NO\";
\$max_num_app_tipologia = \$".mex("var_massimo_numero_appartamenti_per_tipologia",$pag).";
if (strtoupper(\$".mex("var_aggiungi_altre_tipologie",$pag).") == \"".mex("SI",$pag)."\") \$aggiungi_tipologie = \"SI\";
else \$aggiungi_tipologie = \"NO\";
\$max_num_tipologie = \$".mex("var_massimo_numero_altre_tipologie",$pag).";
\$cerca_app_vicini = \"NO\";
if (\$".mex("var_cerca_appartamenti_vicini",$pag)." == \"".mex("SI",$pag)."\") \$cerca_app_vicini = \"SI\";
if (\$".mex("var_cerca_appartamenti_vicini",$pag)." == \"".mex("se possibile",$pag)."\") \$cerca_app_vicini = \"se_poss\";
if (\$".mex("var_cerca_appartamenti_vicini",$pag)." == \"".mex("chiedere",$pag)."\") \$cerca_app_vicini = \"chiedere\";
if (strtoupper(\$".mex("var_chiedi_numero_persone",$pag).") == \"".mex("SI",$pag)."\") \$chiedi_num_persone = \"SI\";
else \$chiedi_num_persone = \"NO\";
\$max_num_persone = \$".mex("var_massimo_numero_persone",$pag).";
\$costo_aggiungi_letti = \$".mex("var_costo_aggiungi_letti",$pag).";
\$max_num_aggiungi_letti = \$".mex("var_massimo_numero_letti_aggiuntivi",$pag).";
if (strtoupper(\$".mex("var_chiedi_costi_aggiuntivi_di_pag_inserzione",$pag).") == \"".mex("SI",$pag)."\") \$mostra_costi_aggiuntivi = \"SI\";
else \$mostra_costi_aggiuntivi = \"NO\";
\$num_colonne_costi_agg = \$".mex("var_numero_colonne_costi_aggiuntivi",$pag).";
if (strtoupper(\$".mex("var_aggiungi_costi_fissi",$pag).") == \"".mex("SI",$pag)."\") \$aggiungi_costi_fissi = \"SI\";
if (strtoupper(\$".mex("var_aggiungi_costi_fissi",$pag).") == \"".mex("NO",$pag)."\") \$aggiungi_costi_fissi = \"NO\";
if (\$aggiungi_costi_fissi != \"SI\" and \$aggiungi_costi_fissi != \"NO\") \$aggiungi_costi_fissi = \"sel\";
unset(\$costi_agg_mostra);
reset (\$".mex("var_costi_aggiuntivi_mostra",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_costi_aggiuntivi_mostra",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$costi_agg_mostra[\$key] = \"SI\";
if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$costi_agg_mostra[\$key] = \"NO\";
} # fine while
\$n_costi_agg_imposti = \$".mex("var_nomi_costi_agg_imposti",$pag).";
\$cat_costi_agg_imposte = \$".mex("var_categorie_costi_agg_imposte",$pag).";
\$num_codici_promo = 0;
unset(\$codici_promo);
unset(\$tipi_codici_promo);
unset(\$costi_codici_promo);
reset (\$".mex("var_campi_codici_promo",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_campi_codici_promo",$pag).")) {
if (strcmp(\$val,\"\")) {
\$tipo_cod_promo = substr(\$".mex("var_costi_campi_codici_promo",$pag)."[\$key],0,1);
\$costo_cod_promo = substr(\$".mex("var_costi_campi_codici_promo",$pag)."[\$key],1);
if ((\$tipo_cod_promo == \"-\" or \$tipo_cod_promo == \"+\") and \$costo_cod_promo) {
\$codici_promo[\$num_codici_promo] = \$val;
\$tipi_codici_promo[\$num_codici_promo] = \$tipo_cod_promo;
\$costi_codici_promo[\$num_codici_promo] = \$costo_cod_promo;
\$num_codici_promo++;
} # fine if ((\$tipo_cod_promo == \"-\" or \$tipo_cod_promo == \"+\") and...
} # fine if (strcmp(\$val,\"\"))
} # fine while
if (strtoupper(\$".mex("var_assegna_con_regola2",$pag).") == \"".mex("SI",$pag)."\") \$assegna_con_regola2 = \"SI\";
else \$assegna_con_regola2 = \"NO\";
unset(\$motivazioni_regola1);
reset (\$".mex("var_considera_motivazioni_regola1",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_considera_motivazioni_regola1",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$motivazioni_regola1[\$key] = \"SI\";
if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$motivazioni_regola1[\$key] = \"NO\";
} # fine while
if (strtoupper(\$".mex("var_mostra_frase_alternativa_regola1",$pag).") == \"".mex("SI",$pag)."\") \$mostra_frase_alternativa_regola1 = \"SI\";
else \$mostra_frase_alternativa_regola1 = \"NO\";
if (strtoupper(\$".mex("var_mostra_caparra",$pag).") == \"".mex("SI",$pag)."\") \$mostra_caparra = \"SI\";
else \$mostra_caparra = \"NO\";
if (strtoupper(\$".mex("var_mostra_richiesta_via_mail",$pag).") == \"".mex("SI",$pag)."\") \$mostra_richiesta_via_mail = \"SI\";
else \$mostra_richiesta_via_mail = \"NO\";
\$indirizzo_email = \$".mex("var_indirizzo_email",$pag).";
if (strtoupper(\$".mex("var_manda_copia_richiesta_email",$pag).") == \"".mex("SI",$pag)."\") \$manda_copia_richiesta_email = \"SI\";
else \$manda_copia_richiesta_email = \"NO\";
if (strtoupper(\$".mex("var_maschera_email",$pag).") == \"".mex("SI",$pag)."\") \$maschera_envelope = \"SI\";
else \$maschera_envelope = \"NO\";
if (strtoupper(\$".mex("var_mostra_giorni_pieni",$pag).") == \"".mex("SI",$pag)."\") \$mostra_giorni_pieni = \"SI\";
else \$mostra_giorni_pieni = \"NO\";
if (strtoupper(\$".mex("var_mostra_bottone_paypal",$pag).") == \"".mex("SI",$pag)."\") \$mostra_bottone_paypal = \"SI\";
else \$mostra_bottone_paypal = \"NO\";
\$nome_modello_paypal = \$".mex("var_nome_modello_paypal",$pag).";
\$utente_messaggio = \$".mex("var_utente_messaggio",$pag).";
if (strtolower(\$utente_messaggio) == strtolower(\"".mex("tutti",$pag)."\")) \$utente_messaggio = \"tutti\";
\$origine_prenotazione = \$".mex("var_origine_prenotazione",$pag).";

\$chiedi_cognome = \$".mex("var_chiedi_cognome",$pag).";
if (strtoupper(\$chiedi_cognome) == \"".mex("SI",$pag)."\") \$chiedi_cognome = \"SI\";
if (strtoupper(\$chiedi_cognome) == \"".mex("NO",$pag)."\") \$chiedi_cognome = \"NO\";
\$chiedi_nome = \$".mex("var_chiedi_nome",$pag).";
if (strtoupper(\$chiedi_nome) == \"".mex("SI",$pag)."\") \$chiedi_nome = \"SI\";
if (strtoupper(\$chiedi_nome) == \"".mex("NO",$pag)."\") \$chiedi_nome = \"NO\";
\$chiedi_email = \$".mex("var_chiedi_email",$pag).";
if (strtoupper(\$chiedi_email) == \"".mex("SI",$pag)."\") \$chiedi_email = \"SI\";
if (strtoupper(\$chiedi_email) == \"".mex("NO",$pag)."\") \$chiedi_email = \"NO\";
\$chiedi_sesso = \$".mex("var_chiedi_sesso",$pag).";
if (strtoupper(\$chiedi_sesso) == \"".mex("SI",$pag)."\") \$chiedi_sesso = \"SI\";
if (strtoupper(\$chiedi_sesso) == \"".mex("NO",$pag)."\") \$chiedi_sesso = \"NO\";
\$chiedi_datanascita = \$".mex("var_chiedi_datanascita",$pag).";
if (strtoupper(\$chiedi_datanascita) == \"".mex("SI",$pag)."\") \$chiedi_datanascita = \"SI\";
if (strtoupper(\$chiedi_datanascita) == \"".mex("NO",$pag)."\") \$chiedi_datanascita = \"NO\";
\$chiedi_documento = \$".mex("var_chiedi_documento",$pag).";
if (strtoupper(\$chiedi_documento) == \"".mex("SI",$pag)."\") \$chiedi_documento = \"SI\";
if (strtoupper(\$chiedi_documento) == \"".mex("NO",$pag)."\") \$chiedi_documento = \"NO\";
\$chiedi_nazione = \$".mex("var_chiedi_nazione",$pag).";
if (strtoupper(\$chiedi_nazione) == \"".mex("SI",$pag)."\") \$chiedi_nazione = \"SI\";
if (strtoupper(\$chiedi_nazione) == \"".mex("NO",$pag)."\") \$chiedi_nazione = \"NO\";
\$chiedi_citta = \$".mex("var_chiedi_citta",$pag).";
if (strtoupper(\$chiedi_citta) == \"".mex("SI",$pag)."\") \$chiedi_citta = \"SI\";
if (strtoupper(\$chiedi_citta) == \"".mex("NO",$pag)."\") \$chiedi_citta = \"NO\";
\$chiedi_regione = \$".mex("var_chiedi_regione",$pag).";
if (strtoupper(\$chiedi_regione) == \"".mex("SI",$pag)."\") \$chiedi_regione = \"SI\";
if (strtoupper(\$chiedi_regione) == \"".mex("NO",$pag)."\") \$chiedi_regione = \"NO\";
\$chiedi_via = \$".mex("var_chiedi_via",$pag).";
if (strtoupper(\$chiedi_via) == \"".mex("SI",$pag)."\") \$chiedi_via = \"SI\";
if (strtoupper(\$chiedi_via) == \"".mex("NO",$pag)."\") \$chiedi_via = \"NO\";
\$chiedi_numcivico = \$".mex("var_chiedi_numcivico",$pag).";
if (strtoupper(\$chiedi_numcivico) == \"".mex("SI",$pag)."\") \$chiedi_numcivico = \"SI\";
if (strtoupper(\$chiedi_numcivico) == \"".mex("NO",$pag)."\") \$chiedi_numcivico = \"NO\";
\$chiedi_cap = \$".mex("var_chiedi_cap",$pag).";
if (strtoupper(\$chiedi_cap) == \"".mex("SI",$pag)."\") \$chiedi_cap = \"SI\";
if (strtoupper(\$chiedi_cap) == \"".mex("NO",$pag)."\") \$chiedi_cap = \"NO\";
\$chiedi_telefono = \$".mex("var_chiedi_telefono",$pag).";
if (strtoupper(\$chiedi_telefono) == \"".mex("SI",$pag)."\") \$chiedi_telefono = \"SI\";
if (strtoupper(\$chiedi_telefono) == \"".mex("NO",$pag)."\") \$chiedi_telefono = \"NO\";
\$chiedi_telefono2 = \$".mex("var_chiedi_telefono2",$pag).";
if (strtoupper(\$chiedi_telefono2) == \"".mex("SI",$pag)."\") \$chiedi_telefono2 = \"SI\";
if (strtoupper(\$chiedi_telefono2) == \"".mex("NO",$pag)."\") \$chiedi_telefono2 = \"NO\";
\$chiedi_telefono3 = \$".mex("var_chiedi_telefono3",$pag).";
if (strtoupper(\$chiedi_telefono3) == \"".mex("SI",$pag)."\") \$chiedi_telefono3 = \"SI\";
if (strtoupper(\$chiedi_telefono3) == \"".mex("NO",$pag)."\") \$chiedi_telefono3 = \"NO\";
\$chiedi_fax = \$".mex("var_chiedi_fax",$pag).";
if (strtoupper(\$chiedi_fax) == \"".mex("SI",$pag)."\") \$chiedi_fax = \"SI\";
if (strtoupper(\$chiedi_fax) == \"".mex("NO",$pag)."\") \$chiedi_fax = \"NO\";
\$chiedi_codfiscale = \$".mex("var_chiedi_codfiscale",$pag).";
if (strtoupper(\$chiedi_codfiscale) == \"".mex("SI",$pag)."\") \$chiedi_codfiscale = \"SI\";
if (strtoupper(\$chiedi_codfiscale) == \"".mex("NO",$pag)."\") \$chiedi_codfiscale = \"NO\";
\$chiedi_partitaiva = \$".mex("var_chiedi_partitaiva",$pag).";
if (strtoupper(\$chiedi_partitaiva) == \"".mex("SI",$pag)."\") \$chiedi_partitaiva = \"SI\";
if (strtoupper(\$chiedi_partitaiva) == \"".mex("NO",$pag)."\") \$chiedi_partitaiva = \"NO\";
\$chiedi_commento = \$".mex("var_chiedi_commento",$pag).";
if (strtoupper(\$chiedi_commento) == \"".mex("SI",$pag)."\") \$chiedi_commento = \"SI\";
if (strtoupper(\$chiedi_commento) == \"".mex("NO",$pag)."\") \$chiedi_commento = \"NO\";
\$chiedi_oracheckin = \$".mex("var_chiedi_oracheckin",$pag).";
if (strtoupper(\$chiedi_oracheckin) == \"".mex("SI",$pag)."\") \$chiedi_oracheckin = \"SI\";
if (strtoupper(\$chiedi_oracheckin) == \"".mex("NO",$pag)."\") \$chiedi_oracheckin = \"NO\";
\$chiedi_metodopagamento = \$".mex("var_chiedi_metodopagamento",$pag).";
if (strtoupper(\$chiedi_metodopagamento) == \"".mex("SI",$pag)."\") \$chiedi_metodopagamento = \"SI\";
if (strtoupper(\$chiedi_metodopagamento) == \"".mex("NO",$pag)."\") \$chiedi_metodopagamento = \"NO\";
unset(\$metodi_pagamento_da_chiedere);
reset (\$".mex("var_metodi_pagamento_da_chiedere",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_metodi_pagamento_da_chiedere",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$metodi_pagamento_da_chiedere[\$key] = \"SI\";
if (strtoupper(\$val) == \"".mex("NO",$pag)."\") \$metodi_pagamento_da_chiedere[\$key] = \"NO\";
} # fine while
\$nomi_metodi_pagamento_imposti = \$".mex("var_nomi_metodi_pagamento_imposti",$pag).";
\$campi_form_personalizzati = \$".mex("var_campi_form_personalizzati",$pag).";
unset(\$chiedi_campi_form_personalizzati);
reset (\$".mex("var_chiedi_campi_form_personalizzati",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_chiedi_campi_form_personalizzati",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$chiedi_campi_form_personalizzati[\$key] = \"SI\";
} # fine while
\$ins_campi_form_personalizzati = \$".mex("var_ins_campi_form_personalizzati",$pag).";
\$campi_form_doc_condizioni = \$".mex("var_campi_form_doc_condizioni",$pag).";
unset(\$chiedi_campi_form_doc_condizioni);
reset (\$".mex("var_chiedi_campi_form_doc_condizioni",$pag).");
while (list (\$key, \$val) = each (\$".mex("var_chiedi_campi_form_doc_condizioni",$pag).")) {
if (strtoupper(\$val) == \"".mex("SI",$pag)."\") \$chiedi_campi_form_doc_condizioni[\$key] = \"SI\";
if (substr(\$val,0,3) == \"op_\") \$chiedi_campi_form_doc_condizioni[\$key] = \$val;
} # fine while

\$mostra_quadro_disp = \"\";
if (strtoupper(\$".mex("var_mostra_quadro_disponibilita",$pag).") == \"".mex("SI",$pag)."\") {
\$mostra_quadro_disp = \"app\";
if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_persone",$pag).") == \"".mex("SI",$pag)."\") \$mostra_quadro_disp = \"pers\";
if (strtoupper(\$".mex("var_raggruppa_quadro_disponibilita_con_regola_2",$pag).") == \"".mex("SI",$pag)."\") \$mostra_quadro_disp = \"reg2\";
} # fine if (strtoupper(\$".mex("var_mostra_quadro_disponibilita",$pag).") == \"".mex("SI",$pag)."\")
\$c_sfondo_tab_disp = \$".mex("var_colore_sfondo_quadro_disponibilita",$pag).";
\$c_inisett_tab_disp = \$".mex("var_colore_inizio_settimana_quadro_disponibilita",$pag).";
\$c_libero_tab_disp = \$".mex("var_colore_libero_quadro_disponibilita",$pag).";
\$c_occupato_tab_disp = \$".mex("var_colore_occupato_quadro_disponibilita",$pag) .";
\$aper_font_tab_disp = \$".mex("var_apertura_font_quadro_disponibilita",$pag).";
\$chiu_font_tab_disp = \$".mex("var_chiusura_font_quadro_disponibilita",$pag).";
if (strtoupper(\$".mex("var_mostra_numero_liberi_quadro_disponibilita",$pag).") == \"".mex("SI",$pag)."\") \$mostra_num_liberi = \"SI\";
else \$mostra_num_liberi = \"NO\";
if (strtoupper(\$".mex("var_allinea_disponibilita_con_arrivo",$pag).") == \"".mex("SI",$pag)."\") \$allinea_disponibilita_con_arrivo = \"SI\";
else \$allinea_disponibilita_con_arrivo = \"NO\";

if (strtoupper(\$".mex("var_mostra_calendario_scelta_date",$pag).") == \"".mex("SI",$pag)."\") \$mostra_calendario_scelta_date = \"SI\";
else \$mostra_calendario_scelta_date = \"NO\";
\$stile_riquadro_calendario = \$".mex("var_stile_riquadro_calendario",$pag).";
\$stile_tabella_calendario = \$".mex("var_stile_tabella_calendario",$pag).";
\$stile_bottoni_calendario = \$".mex("var_stile_bottoni_calendario",$pag).";
\$stile_bottone_apertura_calendario = \$".mex("var_stile_bottone_apertura_calendario",$pag).";
\$spostamento_orizzontale_calendario = \$".mex("var_spostamento_orizzontale_calendario",$pag).";
\$colore_data_attiva_calendario = \$".mex("var_colore_data_attiva_calendario",$pag).";
\$colore_data_selezionata_calendario = \$".mex("var_colore_data_selezionata_calendario",$pag).";

\$apertura_tag_font = \$".mex("var_apertura_tag_font",$pag).";
\$chiusura_tag_font = \$".mex("var_chiusura_tag_font",$pag).";
\$apertura_tag_font_rosse = \$".mex("var_apertura_tag_font_rosse",$pag).";
\$chiusura_tag_font_rosse = \$".mex("var_chiusura_tag_font_rosse",$pag).";
\$stile_tabella_prenotazione = \$".mex("var_stile_tabella_prenotazione",$pag).";
\$file_css_frame = \$".mex("var_file_css_frame",$pag).";
if (strtoupper(\$".mex("var_apri_nuova_finestra_da_frame",$pag).") == \"".mex("SI",$pag)."\") \$apri_nuova_finestra_da_frame = \"SI\";
else \$apri_nuova_finestra_da_frame = \"NO\";
\$larghezza_finestra_da_frame = \$".mex("var_larghezza_finestra_da_frame",$pag).";
\$altezza_finestra_da_frame = \$".mex("var_altezza_finestra_da_frame",$pag).";
\$extra_head_frame = \"$extra_head_frame\";
\$tipo_periodi = \"$m_tipo_periodi\";

# FRASI
\$fr_Euro = \$".mex("var_fr_Valuta_sing",$pag).";
\$fr_Euros = \$".mex("var_fr_Valuta_plur",$pag).";
\$fr_appartamenti = \$".mex("var_fr_appartamenti",$pag).";
\$fr_appartamento = \$".mex("var_fr_appartamento",$pag).";
\$fr_alternativa_regola1 = \$".mex("var_fr_alternativa_regola1",$pag).";
");
for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) fwrite($file,"\$".$fr_frase[$num_fr]." = \$".mex("var_".$fr_frase[$num_fr],$pag).";
");
fwrite($file,"\$fre_Email = \$".mex("var_fre_Email",$pag).";
\$fre_Nome = \$".mex("var_fre_Nome",$pag).";
\$fre_Commento = \$".mex("var_fre_Commento",$pag).";
\$fre_Periodo = \$".mex("var_fre_Periodo",$pag).";
\$fre_dal = \$".mex("var_fre_dal",$pag).";
\$fre_al = \$".mex("var_fre_al",$pag).";
\$fre_Tariffa = \$".mex("var_fre_Tariffa",$pag).";
\$fre_Costi_aggiuntivi = \$".mex("var_fre_Costi_aggiuntivi",$pag).";
\$fre_sett = \$".mex("var_fre_sett",$pag).";
\$fre_Numero_di_appartamenti = \$".mex("var_fre_Numero_di_appartamenti",$pag).";
\$fre_Prezzo_totale = \$".mex("var_fre_Prezzo_totale",$pag).";
\$fre_Riferimento = \$".mex("var_fre_Riferimento",$pag).";
\$fre_Richesta_prenotazione = \$".mex("var_fre_Richesta_prenotazione",$pag).";
\$fre_Caparra = \$".mex("var_fre_Caparra",$pag).";
\$fre_Persone = \$".mex("var_fre_Persone",$pag).";
\$fre_Cognome = \$".mex("var_fre_Cognome",$pag).";
\$fre_Genere = \$".mex("var_fre_Genere",$pag).";
\$fre_Data_di_nascita = \$".mex("var_fre_Data_di_nascita",$pag).";
\$fre_Documento = \$".mex("var_fre_Documento",$pag).";
\$fre_Nazione = \$".mex("var_fre_Nazione",$pag).";
\$fre_Citta = \$".mex("var_fre_Citta",$pag).";
\$fre_Regione = \$".mex("var_fre_Regione",$pag).";
\$fre_Via = \$".mex("var_fre_Via",$pag).";
\$fre_Numero_civico = \$".mex("var_fre_Numero_civico",$pag).";
\$fre_Codice_postale = \$".mex("var_fre_Codice_postale",$pag).";
\$fre_Telefono = \$".mex("var_fre_Telefono",$pag).";
\$fre_Secondo_telefono = \$".mex("var_fre_Secondo_telefono",$pag).";
\$fre_Terzo_telefono = \$".mex("var_fre_Terzo_telefono",$pag).";
\$fre_Fax = \$".mex("var_fre_Fax",$pag).";
\$fre_Codice_fiscale = \$".mex("var_fre_Codice_fiscale",$pag).";
\$fre_Partita_iva = \$".mex("var_fre_Partita_iva",$pag).";
\$fre_Orario_stimato_di_arrivo = \$".mex("var_fre_Orario_stimato_di_arrivo",$pag).";
\$fre_Metodo_di_pagamento_della_caparra = \$".mex("var_fre_Metodo_di_pagamento_della_caparra",$pag).";

# PERIODI NEI MENU
\$menu_periodi = \$".mex("var_periodi_menu",$pag).";

function mex_data(\$messaggio) {
");
if ($lingua_modello != "ita") {
if (@is_file("./includes/lang/$lingua_modello/giorni_mesi.php")) includi_file("./includes/lang/$lingua_modello/giorni_mesi.php",$file);
else if (@is_file("./includes/lang/en/giorni_mesi.php")) includi_file("./includes/lang/en/giorni_mesi.php",$file);
} # fine if ($lingua_modello != "ita")
fwrite($file,"
return \$messaggio;
} # fine function mex_data

");
includi_file("./includes/funzioni_".$M_PHPR_DB_TYPE.".php",$file);
fwrite($file,"

\$numconnessione = connetti_db(\$PHPR_DB_NAME,\$PHPR_DB_HOST,\$PHPR_DB_PORT,\$PHPR_DB_USER,\$PHPR_DB_PASS,\$PHPR_LOAD_EXT);
");
includi_file("./includes/funzioni.php",$file);
includi_file(C_DATI_PATH."/versione.php",$file);
includi_file("./includes/liberasettimane.php",$file);
includi_file("./includes/funzioni_tariffe.php",$file);
includi_file("./includes/funzioni_costi_agg.php",$file);
includi_file("./includes/funzioni_quadro_disp.php",$file);
includi_file("./includes/funzioni_clienti.php",$file);
includi_file("./includes/funzioni_dati_relutenti.php",$file);
if ($campi_form_personalizzati) {
fwrite($file,"
\$campi_pers_comm = esegui_query(\"select valpersonalizza from \$PHPR_TAB_PRE\".\"personalizza where idpersonalizza = 'campi_pers_comm' and idutente = '1' \");
if (numlin_query(\$campi_pers_comm)) {
\$campi_pers_comm = explode(\">\",risul_query(\$campi_pers_comm,0,'valpersonalizza'));
\$num_commenti_pers = count(\$campi_pers_comm);
} # fine if (numlin_query(\$campi_pers_comm))
else \$num_commenti_pers = 0;
");
} # fine if ($campi_form_personalizzati)
elseif ($campi_form_doc_condizioni) fwrite($file,"
\$num_commenti_pers = 0;
");
if ($campi_form_doc_condizioni) {
fwrite($file,"
\$campi_pers_cliente = esegui_query(\"select * from \$PHPR_TAB_PRE\".\"personalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '1' \");
if (numlin_query(\$campi_pers_cliente)) {
\$campi_pers_cliente = explode(\">\",risul_query(\$campi_pers_cliente,0,'valpersonalizza'));
\$num_campi_pers_cliente = count(\$campi_pers_cliente);
} # fine if (numlin_query(\$campi_pers_cliente))
else \$num_campi_pers_cliente = 0;
\$commento_personalizzato_ = \"commento_personalizzato_\";
\$campo_personalizzato_ = \"campo_personalizzato_\";
");
includi_file("./includes/variabili_contratto.php",$file);
includi_file("./includes/funzioni_contratti.php",$file);
includi_file("./includes/funzioni_testo.php",$file);
fwrite($file,"
function crea_trad_var_vett (&\$trad_var_vett) {
\$trad_var_vett = \"\";
");
if (@is_dir("./includes/lang/es")) {
includi_file("./includes/lang/es/visualizza_contratto_var.php",$file);
fwrite($file,"
while (list(\$var_trad_ita,\$var_trad_ext) = each(\$trad_var)) \$trad_var_vett[\$var_trad_ext] = \$var_trad_ita;
unset(\$trad_var);
");
} # fine if (@is_dir("./includes/lang/es"))
if (@is_dir("./includes/lang/en")) {
includi_file("./includes/lang/en/visualizza_contratto_var.php",$file);
fwrite($file,"
while (list(\$var_trad_ita,\$var_trad_ext) = each(\$trad_var)) \$trad_var_vett[\$var_trad_ext] = \$var_trad_ita;
unset(\$trad_var);
");
} # fine if (@is_dir("./includes/lang/en"))
global $lingua_mex;
if ($lingua_mex != "ita" and $lingua_mex != "en" and $lingua_mex != "es") {
if (@is_dir("./includes/lang/$lingua_mex")) {
includi_file("./includes/lang/$lingua_mex/visualizza_contratto_var.php",$file);
fwrite($file,"
while (list(\$var_trad_ita,\$var_trad_ext) = each(\$trad_var)) \$trad_var_vett[\$var_trad_ext] = \$var_trad_ita;
unset(\$trad_var);
");
} # fine if (@is_dir("./includes/lang/$lingua_mex"))
} # fine if ($lingua_mex != "ita" and $lingua_mex != "en" and $lingua_mex != "es")
fwrite($file,"
if (!@is_array(\$trad_var_vett)) \$trad_var_vett['new_line'] = 'avanzamento_riga';
} # fine function crea_trad_var_vett
");
} # fine if ($campi_form_doc_condizioni)

if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
$f_scad_acc = explode("/",$percorso_cartella_modello);
$num_f_scad_acc = count($f_scad_acc);
$file_scad_acc = "";
for ($num1 = 0 ; $num1 < $num_f_scad_acc ; $num1++) if ($f_scad_acc[$num1] != ".") $file_scad_acc .= "../";
$file_scad_acc .= C_FILE_SCADENZA_ACCOUNT;
fwrite($file,"
\$disattivato = \"\";
\$scadenza = trim(@implode(@file(\"$file_scad_acc\")));
\$adesso = date(\"YmdHis\");
if (!\$scadenza or \$scadenza < \$adesso) {
\$disattivato = \"SI\";
echo \"Expired account.<br>\";
} # fine (!\$scadenza or \$scadenza < \$adesso)
if (!\$disattivato) {
");
} # fine if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "")

includi_file("./includes/templates/modello_disponibilita.php",$file);
if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") fwrite($file,"
} # fine if (!\$disattivato)
");
fwrite($file,"
if (!\$framed) {
?>


<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->




$ultima_parte_html
<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  --><?php } # fine if (!\$framed) ?>");
flock($file,3);
fclose($file);
$exec_crea_mod = substr(decoct(@fileperms('./crea_modelli.php')),-3,1);
if ((defined('C_CHMOD_EXEC_MODELLI') and C_CHMOD_EXEC_MODELLI == "SI") or $exec_crea_mod == "7" or $exec_crea_mod == "5") @chmod("$percorso_cartella_modello/$nome_file", 0750);
else @chmod("$percorso_cartella_modello/$nome_file", 0640);


$url_pagina = "";
if ($silenzio != "totale" or ($silenzio != "NO" and $tema_trovato and $framed_mode_example[$tema_sel])) {
$url_pagina = trova_url_pagina($nome_file,$percorso_cartella_modello,$pag);
if ($url_pagina) $url_pagina_link = $url_pagina;
else $url_pagina_link = "$percorso_cartella_modello/$nome_file";
} # fine if ($silenzio != "totale" or ($silenzio != "NO" and...

if ($silenzio == "NO") echo "<br>";
if ($silenzio != "totale") echo mex("Una pagina chiamata",$pag)." <b><a href=\"$url_pagina_link\" target=\"_blank\">$nome_file</a></b> ".mex("è stata creata nella directory",$pag)." \"$percorso_cartella_modello\".<br>";
if ($silenzio == "NO") {
if (defined('C_CARTELLA_CREA_MODELLI')) echo mex("Si può creare un link verso questa pagina dal proprio sito internet",$pag).".<br>";
else echo mex("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag).".<br>";

if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI") {
$altri_domini = @file(C_FILE_DOMINIO);
if ($altri_domini) {
if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
else $percorso_cartella_dominio = $percorso_cartella_modello;
if (substr($percorso_cartella_dominio,0,1) == "/") $percorso_cartella_dominio = substr($percorso_cartella_dominio,1);
if (strcmp($percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
if (substr($percorso_cartella_dominio,0,2) == "./") $percorso_cartella_dominio = substr($percorso_cartella_dominio,2);
$lista_altri_domini = "";
$num_altri_domini = count($altri_domini);
for ($num1 = 0 ; $num1 < $num_altri_domini ; $num1++) {
if ($num1 == 0) $altro_dominio = "https://";
else $altro_dominio = "http://";
$altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
if ($num1 == 0) $url_pagina = $altro_dominio;
if ($altro_dominio != $url_pagina_link) {
$lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
if ($num1 == 0) $lista_altri_domini .= " (".mex("sicuro",$pag).")";
$lista_altri_domini .= "<br>";
} # fine if ($altro_dominio != $url_pagina_link)
} # fine for $num1
if ($lista_altri_domini) echo "<br><br>".mex("Indirizzi alternativi da cui la pagina è raggiungibile",$pag).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
} # fine if ($altri_domini)
} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and C_NASCONDI_MARCA != "SI")

if ($tema_trovato and $framed_mode_example[$tema_sel] and $url_pagina) {
echo "<br><br>".mex("Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito",$pag).":<br>
<textarea rows=4 cols=108 wrap=\"off\" readonly=\"true\">
".htmlspecialchars(str_replace("[page_url]",$url_pagina,$framed_mode_example[$tema_sel]))."
</textarea><br>";
} # fine if ($tema_trovato and $framed_mode_example[$tema_sel] and...
echo "<br>";

} # fine if ($silenzio == "NO")
} # fine if ($file)
else if ($silenzio == "NO") echo mex("Non ho il permesso di scrittura nella cartella",$pag)." $percorso_cartella_modello.<br>";

} # fine if ($continua != "NO")
} # fine function crea_modello_disponibilita







function aggiorna_var_anno_modello_disponibilita ($id_data_ini_periodi_prec,$tableperiodi_prec,$tableperiodi,$tabletransazioniweb,$tablemessaggi,$tipo_periodi) {

global $num_periodi_date,$LIKE,$anno,$estendi_ultima_data;
$n_num_periodi_date = 0;
if ($id_data_ini_periodi_prec) {
for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
global ${"inizioperiodo".$num1},${"fineperiodo".$num1},${"intervalloperiodo".$num1};
$inizioperiodo = aggslashdb(${"inizioperiodo".$num1});
$fineperiodo = aggslashdb(${"fineperiodo".$num1});
$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi_prec where datainizio = '$inizioperiodo' ");
$num_idinizioperiodo = numlin_query($idinizioperiodo);
if ($num_idinizioperiodo == 0) { $idinizioperiodo = 10000; }
else { $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi'); }
$inizioperiodo = $idinizioperiodo;
$idfineperiodo = esegui_query("select idperiodi from $tableperiodi_prec where datafine = '$fineperiodo' ");
$num_idfineperiodo = numlin_query($idfineperiodo);
if ($num_idfineperiodo == 0) { $idfineperiodo = -1; }
else { $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi'); }
$fineperiodo = $idfineperiodo;
$intervalloperiodo = aggslashdb(${"intervalloperiodo".$num1});
if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1)) $fineperiodo = $id_data_ini_periodi_prec + $intervalloperiodo;
if (($fineperiodo - $intervalloperiodo) >= $id_data_ini_periodi_prec) {
if ($inizioperiodo < $id_data_ini_periodi_prec) {
for ($num2 = $inizioperiodo ; $num2 <= $fineperiodo ; $num2 = $num2 + $intervalloperiodo) {
if ($num2 >= $id_data_ini_periodi_prec) {
$inizioperiodo = $num2;
break;
} # fine if ($num2 >= $id_data_ini_periodi_prec)
} # fine for $num2
} # fine if ($inizioperiodo < $id_data_ini_periodi_prec)
$n_inizioperiodo[$n_num_periodi_date] = $inizioperiodo - $id_data_ini_periodi_prec + 1;
$n_fineperiodo[$n_num_periodi_date] = $fineperiodo - $id_data_ini_periodi_prec + 1;
$n_intervalloperiodo[$n_num_periodi_date] = $intervalloperiodo;
$n_num_periodi_date++;
} # fine if (($fineperiodo - $intervalloperiodo) >= $id_data_ini_periodi_prec or...
} # fine for $num1
} # fine if ($id_data_ini_periodi_prec)

if ($estendi_ultima_data == "SI" and !$id_data_ini_periodi_prec) {
$n_num_periodi_date = 1;
global $inizioperiodo0,$fineperiodo0,$intervalloperiodo0;
if (($num_periodi_date - 1) != 0) global ${"fineperiodo".($num_periodi_date - 1)},${"intervalloperiodo".($num_periodi_date - 1)};
$n_intervalloperiodo[0] = ${"intervalloperiodo".($num_periodi_date - 1)};
$inizioperiodo = ${"fineperiodo".($num_periodi_date - 1)};
if ($tipo_periodi == "g") $aggiungi_giorni = 1;
else $aggiungi_giorni = 7;
$anno_inizio = substr($inizioperiodo,0,4);
$mese_inizio = substr($inizioperiodo,5,2);
$giorno_inizio = substr($inizioperiodo,8,2);
for ($num1 = 0 ; $num1 < 2000 ; $num1++) {
$datainizio = date("Y-m-d",mktime(0,0,0,$mese_inizio,$giorno_inizio,$anno_inizio));
$datainizio = esegui_query("select * from $tableperiodi where datainizio = '$datainizio'");
if (numlin_query($datainizio) == 1) {
$n_inizioperiodo[0] = risul_query($datainizio,0,'idperiodi');
break;
} # fine if (numlin_query($datainizio) == 1)
$giorno_inizio = $giorno_inizio + ($n_intervalloperiodo[0] * $aggiungi_giorni);
} # fine for $num1
$n_fineperiodo[0] = $n_inizioperiodo[0];
} # fine if ($estendi_ultima_data == "SI" and !$id_data_ini_periodi_prec)

for ($num1 = 0 ; $num1 < $n_num_periodi_date ; $num1++) {
$inizioperiodo = $n_inizioperiodo[$num1];
$fineperiodo = $n_fineperiodo[$num1];
$inizioperiodo = esegui_query("select datainizio from $tableperiodi where idperiodi = '$inizioperiodo' ");
$inizioperiodo = @risul_query($inizioperiodo,0,'datainizio');
$fineperiodo = esegui_query("select datafine from $tableperiodi where idperiodi = '$fineperiodo' ");
$fineperiodo = @risul_query($fineperiodo,0,'datafine');
if (!$inizioperiodo or !$fineperiodo) $n_num_periodi_date = 0;
${"inizioperiodo".$num1} = $inizioperiodo;
${"fineperiodo".$num1} = $fineperiodo;
${"intervalloperiodo".$num1} = $n_intervalloperiodo[$num1];
} # fine for $num1
$num_periodi_date = $n_num_periodi_date;
if (!$num_periodi_date) $inizioperiodo0 = "";

if ($num_periodi_date != 0) {
if ($id_data_ini_periodi_prec) {
$tabelle_lock = array("$tabletransazioniweb","$tablemessaggi");
$altre_tab_lock = array("$tableperiodi_prec","$tableperiodi");
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
$data_ini_periodi_prec = esegui_query("select datainizio from $tableperiodi_prec where idperiodi = '$id_data_ini_periodi_prec' ");
$data_ini_periodi_prec = risul_query($data_ini_periodi_prec,0,'datainizio');
$da_aggiornare = esegui_query("select idmessaggi,dati_messaggio3,dati_messaggio4,dati_messaggio9,dati_messaggio14 from $tablemessaggi where tipo_messaggio = 'rprenota' and dati_messaggio1 = 'da_inserire' and dati_messaggio18 = '".($anno - 1)."' ");
$num_da_aggiornare = numlin_query($da_aggiornare);
for ($num1 = 0 ; $num1 < $num_da_aggiornare ; $num1++) {
$num_tipologie = risul_query($da_aggiornare,$num1,'dati_messaggio3');
$id_messaggio = risul_query($da_aggiornare,$num1,'idmessaggi');
$date_inizio = explode(",",risul_query($da_aggiornare,$num1,'dati_messaggio4'));
$aggiornare = "SI";
for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
if ($date_inizio[($n_t - 1)] < $data_ini_periodi_prec) $aggiornare = "NO";
} # fine for $n_t
if ($aggiornare == "SI") {
$numcostiagg_dt = explode(",",risul_query($da_aggiornare,$num1,'dati_messaggio9'));
$id_periodi_costo_dt = explode(";",risul_query($da_aggiornare,$num1,'dati_messaggio14'));
$n_id_periodi_costo = "";
for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
if ($n_t != 1) $n_id_periodi_costo .= ";";
$numcostiagg = $numcostiagg_dt[($n_t - 1)];
$id_periodi_costo_dt2 = explode(":",$id_periodi_costo_dt[($n_t - 1)]);
for ($numca = 1 ; $numca <= $numcostiagg ; $numca++) {
if ($numca != 1) $n_id_periodi_costo .= ":";
$id_periodi_costo = explode(",",$id_periodi_costo_dt2[($numca - 1)]);
$num_id_periodi_costo = count($id_periodi_costo);
for ($numpc = 0 ; $numpc < $num_id_periodi_costo ; $numpc++) {
if ($numpc != 0) $n_id_periodi_costo .= ",";
if ($id_periodi_costo[$numpc]) $n_id_periodi_costo .= $id_periodi_costo[$numpc] - $id_data_ini_periodi_prec + 1;
} # fine for $numpc
} # fine for $numca
} # fine for $n_t
esegui_query("update $tablemessaggi set dati_messaggio14 = '$n_id_periodi_costo', dati_messaggio18 = '$anno' where idmessaggi = '".aggslashdb($id_messaggio)."' ");
} # fine if ($aggiornare == "SI")
} # fine for $num1
unlock_tabelle($tabelle_lock);
} # fine if ($id_data_ini_periodi_prec)
} # fine if ($num_periodi_date != 0)

} # fine funtcion aggiorna_var_anno_modello_disponibilita







?>